@@ -27,10 +27,7 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreednd.h>
-#include <gtk/gtktreesortable.h>
-#include <gtk/gtkicontheme.h>
+#include <gtk/gtk.h>
 
 #include "burn-basics.h"
 
@@ -434,7 +431,7 @@ brasero_data_tree_model_get_value (GtkTreeModel *model,
 			if (node->is_exploring)
 				g_value_set_string (value, _("(loading ...)"));
 			else
-				g_value_set_string (value, _("empty"));
+				g_value_set_string (value, _("Empty"));
 
 			return;
 
@@ -574,7 +571,7 @@ brasero_data_tree_model_get_value (GtkTreeModel *model,
 
 			nb_items = brasero_file_node_get_n_children (node);
 			if (!nb_items)
-				g_value_set_string (value, _("empty"));
+				g_value_set_string (value, _("Empty"));
 			else if (nb_items == 1)
 				g_value_set_string (value, _("1 item"));
 			else {
