@@ -59,6 +59,7 @@ struct _BraseroDataVFSPrivate
 	BraseroIOJobBase *load_uri;
 	BraseroIOJobBase *load_contents;
 
+	guint replace_sym:1;
 	guint filter_hidden:1;
 	guint filter_broken_sym:1;
 };
@@ -385,7 +386,8 @@ brasero_data_vfs_directory_check_symlink_loop (BraseroDataVFS *self,
 
 		/* The next graft point must be the natural parent of this one */
 		next = parent->parent;
-		if (!next || next->is_root) {
+		if (!next || next->is_root || next->is_fake) {
+			/* It's not we're done */
 			g_free (parent_uri);
 			break;
 		}
@@ -561,7 +563,8 @@ brasero_data_vfs_load_directory (BraseroDataVFS *self,
 	brasero_io_load_directory (priv->io,
 				   uri,
 				   priv->load_contents,
-				   BRASERO_IO_INFO_PERM,
+				   BRASERO_IO_INFO_PERM|
+				  (priv->replace_sym ? BRASERO_IO_INFO_FOLLOW_SYMLINK:BRASERO_IO_INFO_NONE),
 				   registered);
 
 	/* Only emit a signal if state changed. Some widgets need to know if 
@@ -782,7 +785,8 @@ brasero_data_vfs_load_node (BraseroDataVFS *self,
 	brasero_io_get_file_info (priv->io,
 				  uri,
 				  priv->load_uri,
-				  flags,
+				  flags|
+				  (priv->replace_sym ? BRASERO_IO_INFO_FOLLOW_SYMLINK:BRASERO_IO_INFO_NONE),
 				  registered);
 
 	/* Only emit a signal if state changed. Some widgets need to know if 
@@ -811,39 +815,19 @@ brasero_data_vfs_loading_node (BraseroDataVFS *self,
 
 	priv = BRASERO_DATA_VFS_PRIVATE (self);
 
-	if (!node->is_reloading) {
-		gchar *name;
-		GFile *vfs_uri;
+	if (!node->is_reloading
+	&&   BRASERO_FILE_NODE_NAME (node)
+	&&  !strcmp (BRASERO_FILE_NODE_NAME (node), G_DIR_SEPARATOR_S)) {
+		/* This is a root directory: we don't add it since a
+		 * child of the root directory can't be a root itself.
+		 * So we add all its contents under its parent. Remove
+		 * the loading node as well. 
+		 * Be careful in the next functions not to use node. */
+		brasero_data_vfs_load_directory (self, node->parent, uri);
 
-		/* g_path_get_basename is not comfortable with uri related
-		 * to the root directory so check that before */
-		vfs_uri = g_file_new_for_uri (uri);
-		name = g_file_get_basename (vfs_uri);
-		g_object_unref (vfs_uri);
-
-
-		/* NOTE and reminder names are already unescaped; the following
-		 * is not needed: unescaped_name = g_uri_unescape_string (name,
-		 * NULL); */
-
-		if (!name)
-			return TRUE;
-
-		if (!strcmp (name, G_DIR_SEPARATOR_S)) {
-			g_free (name);
-
-			/* This is a root directory: we don't add it since a
-			 * child of the root directory can't be a root itself.
-			 * So we add all its contents under its parent. Remove
-			 * the loading node as well. 
-			 * Be careful in the next functions not to use node. */
-			brasero_data_vfs_load_directory (self, node->parent, uri);
-
-			/* node was invalidated: return FALSE */
-			brasero_data_project_remove_node (BRASERO_DATA_PROJECT (self), node);
-			return FALSE;
-		}
-		g_free (name);
+		/* node was invalidated: return FALSE */
+		brasero_data_project_remove_node (BRASERO_DATA_PROJECT (self), node);
+		return FALSE;
 	}
 
 	/* FIXME: we could know right from the start if that node is is_loading */
@@ -986,7 +970,8 @@ brasero_data_vfs_load_mime (BraseroDataVFS *self,
 	reference = brasero_data_project_reference_new (BRASERO_DATA_PROJECT (self), node);
 	result = brasero_data_vfs_load_node (self,
 					     BRASERO_IO_INFO_MIME|
-					     BRASERO_IO_INFO_URGENT,
+					     BRASERO_IO_INFO_URGENT|
+					     (priv->replace_sym ? BRASERO_IO_INFO_FOLLOW_SYMLINK:BRASERO_IO_INFO_NONE),
 					     reference,
 					     uri);
 	g_free (uri);
@@ -1019,7 +1004,8 @@ brasero_data_vfs_node_added (BraseroDataProject *project,
 		if (brasero_data_vfs_loading_node (self, node, uri))
 			goto chain;
 
-		goto chain;
+		/* The node was invalidated. So there's no need to pass it on */
+		return FALSE;
 	}
 
 	/* NOTE: a symlink pointing to a directory will return TRUE. */
@@ -1187,6 +1173,24 @@ brasero_data_vfs_filter_broken_sym_changed (GConfClient *client,
 	priv->filter_broken_sym = gconf_value_get_bool (value);
 }
 
+static void
+brasero_data_vfs_replace_sym_changed (GConfClient *client,
+				      guint cxn,
+				      GConfEntry *entry,
+				      gpointer data)
+{
+	BraseroDataVFSPrivate *priv;
+	GConfValue *value;
+
+	priv = BRASERO_DATA_VFS_PRIVATE (data);
+
+	value = gconf_entry_get_value (entry);
+	if (value->type != GCONF_VALUE_BOOL)
+		return;
+
+	priv->replace_sym = gconf_value_get_bool (value);
+}
+
 static void
 brasero_data_vfs_init (BraseroDataVFS *object)
 {
@@ -1197,12 +1201,16 @@ brasero_data_vfs_init (BraseroDataVFS *object)
 
 	/* load the fitering rules */
 	client = gconf_client_get_default ();
+	priv->replace_sym = gconf_client_get_bool (client,
+						   BRASERO_REPLACE_SYMLINK_KEY,
+						   NULL);
 	priv->filter_hidden = gconf_client_get_bool (client,
 						     BRASERO_FILTER_HIDDEN_KEY,
 						     NULL);
 	priv->filter_broken_sym = gconf_client_get_bool (client,
 							 BRASERO_FILTER_BROKEN_SYM_KEY,
 							 NULL);
+
 	gconf_client_notify_add (client,
 				 BRASERO_FILTER_HIDDEN_KEY,
 				 brasero_data_vfs_filter_hidden_changed,
@@ -1215,6 +1223,12 @@ brasero_data_vfs_init (BraseroDataVFS *object)
 				 object,
 				 NULL,
 				 NULL);
+	gconf_client_notify_add (client,
+				 BRASERO_REPLACE_SYMLINK_KEY,
+				 brasero_data_vfs_replace_sym_changed,
+				 object,
+				 NULL,
+				 NULL);
 	g_object_unref (client);
 
 	/* create the hash tables */
