@@ -30,8 +30,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
 #include "burn-basics.h"
 #include "burn-session.h"
@@ -111,7 +110,9 @@ struct _BraseroDiscIface {
 							 BraseroBurnFlag flags);
 
 	/* virtual functions */
-	BraseroDiscResult	(*get_status)		(BraseroDisc *disc);
+	BraseroDiscResult	(*get_status)		(BraseroDisc *disc,
+							 gint *remaining,
+							 gchar **current_task);
 
 	BraseroDiscResult	(*load_track)		(BraseroDisc *disc,
 							 BraseroDiscTrack *track);
@@ -123,8 +124,6 @@ struct _BraseroDiscIface {
 	BraseroDiscResult	(*set_session_contents)	(BraseroDisc *disc,
 							 BraseroBurnSession *session);
 
-	BraseroDiscResult	(*can_add_uri)		(BraseroDisc *disc,
-							 const gchar *uri);
 	BraseroDiscResult	(*add_uri)		(BraseroDisc *disc,
 							 const gchar *uri);
 
@@ -141,9 +140,6 @@ struct _BraseroDiscIface {
 	guint			(*add_ui)		(BraseroDisc *disc,
 							 GtkUIManager *manager,
 							 GtkWidget *message);
-
-	void			(*set_drive)		(BraseroDisc *disc,
-							 BraseroDrive *drive);
 };
 
 GType brasero_disc_get_type ();
@@ -156,9 +152,6 @@ brasero_disc_add_ui (BraseroDisc *disc,
 BraseroDiscResult
 brasero_disc_add_uri (BraseroDisc *disc, const gchar *escaped_uri);
 
-BraseroDiscResult
-brasero_disc_can_add_uri (BraseroDisc *disc, const gchar *escaped_uri);
-
 gboolean
 brasero_disc_get_selected_uri (BraseroDisc *disc, gchar **uri);
 
@@ -175,7 +168,9 @@ void
 brasero_disc_reset (BraseroDisc *disc);
 
 BraseroDiscResult
-brasero_disc_get_status (BraseroDisc *disc);
+brasero_disc_get_status (BraseroDisc *disc,
+			 gint *remaining,
+			 gchar **current_task);
 
 BraseroDiscResult
 brasero_disc_get_track (BraseroDisc *disc,
@@ -208,10 +203,6 @@ brasero_track_clear (BraseroDiscTrack *track);
 void
 brasero_track_free (BraseroDiscTrack *track);
 
-void
-brasero_disc_set_current_drive (BraseroDisc *disc,
-				BraseroDrive *drive);
-
 GtkWidget *
 brasero_disc_get_use_info_notebook (void);
 
