@@ -32,22 +32,14 @@
 
 #include <gio/gio.h>
 
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkbox.h>
+#include <gtk/gtk.h>
 
 #include "burn-basics.h"
-#include "burn-medium.h"
+#include "brasero-medium.h"
 #include "burn-debug.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 #include "brasero-utils.h"
+#include "brasero-session-cfg.h"
 #include "brasero-drive-properties.h"
 
 typedef struct _BraseroDrivePropertiesPrivate BraseroDrivePropertiesPrivate;
@@ -55,16 +47,13 @@ struct _BraseroDrivePropertiesPrivate
 {
 	GtkWidget *speed;
 	GtkWidget *dummy;
+	GtkWidget *multi;
 	GtkWidget *burnproof;
 	GtkWidget *notmp;
 	GtkWidget *eject;
 
 	GtkWidget *tmpdir;
 	GtkWidget *tmpdir_size;
-
-	gchar *previous_path;
-
-	guint check_filesystem:1;
 };
 
 #define BRASERO_DRIVE_PROPERTIES_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_DRIVE_PROPERTIES, BraseroDrivePropertiesPrivate))
@@ -75,7 +64,6 @@ enum {
 	PROP_NUM
 };
 
-static GtkDialogClass* parent_class = NULL;
 
 G_DEFINE_TYPE (BraseroDriveProperties, brasero_drive_properties, GTK_TYPE_DIALOG);
 
@@ -100,6 +88,9 @@ brasero_drive_properties_get_flags (BraseroDriveProperties *self)
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->burnproof)))
 		flags |= BRASERO_BURN_FLAG_BURNPROOF;
 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->multi)))
+		flags |= BRASERO_BURN_FLAG_MULTI;
+
 	return flags;
 }
 
@@ -133,17 +124,14 @@ brasero_drive_properties_get_tmpdir (BraseroDriveProperties *self)
 	return gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (priv->tmpdir));
 }
 
-static gboolean
+static void
 brasero_drive_properties_set_tmpdir_info (BraseroDriveProperties *self,
-					  const gchar *path,
-					  gboolean warn)
+					  const gchar *path)
 {
 	GFile *file;
 	gchar *string;
 	GFileInfo *info;
-	GError *error = NULL;
 	guint64 vol_size = 0;
-	const gchar *filesystem;
 	BraseroDrivePropertiesPrivate *priv;
 
 	priv = BRASERO_DRIVE_PROPERTIES_PRIVATE (self);
@@ -151,70 +139,21 @@ brasero_drive_properties_set_tmpdir_info (BraseroDriveProperties *self,
 	/* get the volume free space */
 	file = g_file_new_for_commandline_arg (path);
 	if (!file) {
-		BRASERO_BURN_LOG ("impossible to retrieve size for %s", path);
-		gtk_label_set_text (GTK_LABEL (priv->tmpdir_size), _("unknown"));
-		return FALSE;
+		BRASERO_BURN_LOG ("Impossible to retrieve size for %s", path);
+		gtk_label_set_text (GTK_LABEL (priv->tmpdir_size), _("Unknown"));
+		return;
 	}
 
 	info = g_file_query_filesystem_info (file,
-					     G_FILE_ATTRIBUTE_FILESYSTEM_FREE ","
-					     G_FILE_ATTRIBUTE_FILESYSTEM_TYPE,
+					     G_FILE_ATTRIBUTE_FILESYSTEM_FREE,
 					     NULL,
-					     &error);
+					     NULL);
 	g_object_unref (file);
 
-	if (error) {
-		g_object_unref (info);
-
-		BRASERO_BURN_LOG ("impossible to retrieve size for %s (%s)", path, error->message);
-		g_error_free (error);
-
-		gtk_label_set_text (GTK_LABEL (priv->tmpdir_size), _("unknown"));
-		return FALSE;
-	}
-
-	/* NOTE/FIXME: also check, probably best at start or in a special dialog
-	 * whether quotas or any other limitation enforced on the system may not
-	 * get in out way. Think getrlimit (). */
-
-	/* check the filesystem type: the problem here is that some
-	 * filesystems have a maximum file size limit of 4 GiB and more than
-	 * often we need a temporary file size of 4 GiB or more. */
-	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
-	if (priv->check_filesystem
-	&&  filesystem
-	&& !strcmp (filesystem, "msdos")) {
-		gint answer;
-		GtkWidget *dialog;
-		GtkWidget *toplevel;
-
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-						 GTK_DIALOG_DESTROY_WITH_PARENT |
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_WARNING,
-						 GTK_BUTTONS_NONE,
-						 _("Do you really want to choose this location?"));
-
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("The filesystem on this volume doesn't support large files (size over 2 GiB)."
-							    "\nThis can be a problem when writing DVDs or large images."));
-
-		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-					_("_Keep current location"), GTK_RESPONSE_CANCEL,
-					_("_Change location"), GTK_RESPONSE_OK,
-					NULL);
-
-		gtk_widget_show_all (dialog);
-		answer = gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-
-		if (answer != GTK_RESPONSE_OK) {
-			g_object_unref (info);
-			return FALSE;
-		}
-
-		priv->check_filesystem = 1;
+	if (!info) {
+		BRASERO_BURN_LOG ("Impossible to retrieve size for %s", path);
+		gtk_label_set_text (GTK_LABEL (priv->tmpdir_size), _("Unknown"));
+		return;
 	}
 
 	vol_size = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_FILESYSTEM_FREE);
@@ -223,44 +162,23 @@ brasero_drive_properties_set_tmpdir_info (BraseroDriveProperties *self,
 	string = brasero_utils_get_size_string (vol_size, TRUE, TRUE);
 	gtk_label_set_text (GTK_LABEL (priv->tmpdir_size), string);
 	g_free (string);
-
-	return TRUE;
 }
 
 static void
-brasero_drive_properties_tmpdir_changed_cb (GtkFileChooser *chooser,
-					    BraseroDriveProperties *self)
+brasero_drive_properties_tmpdir_changed (GtkFileChooser *chooser,
+					 BraseroDriveProperties *self)
 {
 	gchar *path;
-	gboolean result;
 	BraseroDrivePropertiesPrivate *priv;
 
 	priv = BRASERO_DRIVE_PROPERTIES_PRIVATE (self);
 
-	priv->check_filesystem = 1;
 	path = gtk_file_chooser_get_filename (chooser);
-	result = brasero_drive_properties_set_tmpdir_info (self, path, TRUE);
-	g_free (path);
-
-	if (result) {
-		if (priv->previous_path)
-			g_free (priv->previous_path);
-
-		priv->previous_path = gtk_file_chooser_get_filename (chooser);
+	if (!path)
 		return;
-	}
 
-	g_signal_handlers_block_by_func (chooser,
-					 brasero_drive_properties_tmpdir_changed_cb,
-					 self);
-	if (priv->previous_path)
-		gtk_file_chooser_set_filename (chooser, priv->previous_path);
-	else
-		gtk_file_chooser_set_filename (chooser, g_get_tmp_dir ());
-
-	g_signal_handlers_unblock_by_func (chooser,
-					   brasero_drive_properties_tmpdir_changed_cb,
-					   self);
+	brasero_drive_properties_set_tmpdir_info (self, path);
+	g_free (path);
 }
 
 void
@@ -274,21 +192,173 @@ brasero_drive_properties_set_tmpdir (BraseroDriveProperties *self,
 	if (!path)
 		path = g_get_tmp_dir ();
 
-	priv->check_filesystem = 0;
-	brasero_drive_properties_set_tmpdir_info (self, path, FALSE);
-
-	g_signal_handlers_block_by_func (GTK_FILE_CHOOSER (priv->tmpdir),
-					 brasero_drive_properties_tmpdir_changed_cb,
-					 self);
 	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (priv->tmpdir), path);
-	g_signal_handlers_unblock_by_func (GTK_FILE_CHOOSER (priv->tmpdir),
-					   brasero_drive_properties_tmpdir_changed_cb,
-					   self);
+	brasero_drive_properties_set_tmpdir_info (self, path);
+}
 
-	if (priv->previous_path)
-		g_free (priv->previous_path);
+static gboolean
+brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
+				       const gchar *path)
+{
+	GFile *file;
+	GFileInfo *info;
+	GError *error = NULL;
+	const gchar *filesystem;
+	BraseroDrivePropertiesPrivate *priv;
 
-	priv->previous_path = g_strdup (path);
+	priv = BRASERO_DRIVE_PROPERTIES_PRIVATE (self);
+
+	file = g_file_new_for_commandline_arg (path);
+	if (!file)
+		return TRUE;
+
+	info = g_file_query_info (file,
+				  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
+				  G_FILE_QUERY_INFO_NONE,
+				  NULL,
+				  &error);
+	if (error) {
+		gint answer;
+		gchar *string;
+		GtkWidget *dialog;
+		GtkWidget *toplevel;
+
+		if (error)
+			return TRUE;
+
+		/* Tell the user what went wrong */
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
+		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
+						 GTK_DIALOG_DESTROY_WITH_PARENT |
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_WARNING,
+						 GTK_BUTTONS_NONE,
+						 _("Do you really want to choose this location?"));
+
+		string = g_strdup_printf ("%s.", error->message);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", string);
+		g_error_free (error);
+		g_free (string);
+
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					_("_Keep Current Location"), GTK_RESPONSE_CANCEL,
+					_("_Change Location"), GTK_RESPONSE_OK,
+					NULL);
+
+		gtk_widget_show_all (dialog);
+		answer = gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+
+		g_object_unref (info);
+		g_object_unref (file);
+		if (answer == GTK_RESPONSE_OK)
+			return FALSE;
+
+		return TRUE;
+	}
+
+	if (!g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE)) {
+		gint answer;
+		gchar *string;
+		GtkWidget *dialog;
+		GtkWidget *toplevel;
+
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
+		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
+						 GTK_DIALOG_DESTROY_WITH_PARENT |
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_WARNING,
+						 GTK_BUTTONS_NONE,
+						 _("Do you really want to choose this location?"));
+
+		string = g_strdup_printf ("%s.", _("You do not have the required permission to write at this location"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", string);
+		g_free (string);
+
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					_("_Keep Current Location"), GTK_RESPONSE_CANCEL,
+					_("_Change Location"), GTK_RESPONSE_OK,
+					NULL);
+
+		gtk_widget_show_all (dialog);
+		answer = gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+
+		g_object_unref (info);
+		g_object_unref (file);
+		if (answer == GTK_RESPONSE_OK)
+			return FALSE;
+
+		return TRUE;
+	}
+
+	g_object_unref (info);
+	info = g_file_query_filesystem_info (file,
+					     G_FILE_ATTRIBUTE_FILESYSTEM_TYPE,
+					     NULL,
+					     &error);
+	g_object_unref (file);
+
+	/* NOTE/FIXME: also check, probably best at start or in a special dialog
+	 * whether quotas or any other limitation enforced on the system may not
+	 * get in out way. Think getrlimit (). */
+
+	/* check the filesystem type: the problem here is that some
+	 * filesystems have a maximum file size limit of 4 GiB and more than
+	 * often we need a temporary file size of 4 GiB or more. */
+	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
+	if (filesystem && !strcmp (filesystem, "msdos")) {
+		gint answer;
+		GtkWidget *dialog;
+		GtkWidget *toplevel;
+
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
+		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
+						 GTK_DIALOG_DESTROY_WITH_PARENT |
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_WARNING,
+						 GTK_BUTTONS_NONE,
+						 _("Do you really want to choose this location?"));
+
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("The filesystem on this volume does not support large files (size over 2 GiB)."
+							    "\nThis can be a problem when writing DVDs or large images."));
+
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					_("_Keep Current Location"), GTK_RESPONSE_CANCEL,
+					_("_Change Location"), GTK_RESPONSE_OK,
+					NULL);
+
+		gtk_widget_show_all (dialog);
+		answer = gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+
+		g_object_unref (info);
+		if (answer == GTK_RESPONSE_OK)
+			return FALSE;
+	}
+	else if (info)
+		g_object_unref (info);
+
+	return TRUE;
+}
+
+static void
+brasero_drive_properties_response (GtkDialog *dialog,
+				   gint response,
+				   gpointer NULL_data)
+{
+	BraseroDrivePropertiesPrivate *priv;
+	gchar *path;
+
+	priv = BRASERO_DRIVE_PROPERTIES_PRIVATE (dialog);
+	if (response != GTK_RESPONSE_ACCEPT)
+		return;
+
+	path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (priv->tmpdir));
+	if (!brasero_drive_properties_check_tmpdir (BRASERO_DRIVE_PROPERTIES (dialog), path))
+		g_signal_stop_emission_by_name (dialog, "response");
+	g_free (path);
 }
 
 static void
@@ -343,6 +413,11 @@ brasero_drive_properties_set_flags (BraseroDriveProperties *self,
 						   flags,
 						   supported,
 						   compulsory);
+	brasero_drive_properties_set_toggle_state (priv->multi,
+						   BRASERO_BURN_FLAG_MULTI,
+						   flags,
+						   supported,
+						   compulsory);
 }
 
 static gchar *
@@ -351,14 +426,18 @@ brasero_drive_properties_format_disc_speed (BraseroMedia media,
 {
 	gchar *text;
 
-	if (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))
+	if (media & BRASERO_MEDIUM_DVD)
 		text = g_strdup_printf (_("%.1f x (DVD)"),
 					BRASERO_RATE_TO_SPEED_DVD (rate));
 	else if (media & BRASERO_MEDIUM_CD)
 		text = g_strdup_printf (_("%.1f x (CD)"),
 					BRASERO_RATE_TO_SPEED_CD (rate));
+	else if (media & BRASERO_MEDIUM_BD)
+		text = g_strdup_printf (_("%.1f x (BD)"),
+					BRASERO_RATE_TO_SPEED_BD (rate));
 	else
-		text = g_strdup_printf (_("%.1f x (DVD) %.1f x (CD)"),
+		text = g_strdup_printf (_("%.1f x (BD) %.1f x (DVD) %.1f x (CD)"),
+					BRASERO_RATE_TO_SPEED_BD (rate),
 					BRASERO_RATE_TO_SPEED_DVD (rate),
 					BRASERO_RATE_TO_SPEED_CD (rate));
 
@@ -457,6 +536,7 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 	GtkTreeModel *model;
 	GtkWidget *label;
 	GtkWidget *box;
+	gchar *string;
 
 	priv = BRASERO_DRIVE_PROPERTIES_PRIVATE (object);
 
@@ -472,10 +552,12 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 						    G_TYPE_INT64));
 
 	priv->speed = gtk_combo_box_new_with_model (model);
+	string = g_strdup_printf ("<b>%s</b>", _("Burning speed"));
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
-			    brasero_utils_pack_properties (_("<b>Burning speed</b>"),
+			    brasero_utils_pack_properties (string,
 							   priv->speed, NULL),
 			    FALSE, FALSE, 0);
+	g_free (string);
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->speed), renderer, TRUE);
@@ -488,18 +570,23 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 	priv->burnproof = gtk_check_button_new_with_mnemonic (_("Use burn_proof (decrease the risk of failures)"));
 	priv->eject = gtk_check_button_new_with_mnemonic (_("_Eject after burning"));
 	priv->notmp = gtk_check_button_new_with_mnemonic (_("Burn the image directly _without saving it to disc"));
+	priv->multi = gtk_check_button_new_with_mnemonic (_("Leave the disc _open to add other files later"));
+	gtk_widget_set_tooltip_text (priv->multi, _("Allow to add more data to the disc later"));
 
+	string = g_strdup_printf ("<b>%s</b>", _("Options"));
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
-			    brasero_utils_pack_properties (_("<b>Options</b>"),
+			    brasero_utils_pack_properties (string,
 							   priv->eject,
 							   priv->dummy,
 							   priv->burnproof,
+							   priv->multi,
 							   priv->notmp,
 							   NULL),
 			    FALSE,
 			    FALSE, 0);
+	g_free (string);
 
-	priv->tmpdir = gtk_file_chooser_button_new (_("Directory for temporary files"),
+	priv->tmpdir = gtk_file_chooser_button_new (_("Location for Temporary Files"),
 						    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
 	box = gtk_hbox_new (FALSE, 6);
@@ -514,45 +601,41 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 	gtk_widget_show (priv->tmpdir_size);
 	gtk_box_pack_start (GTK_BOX (box), priv->tmpdir_size, FALSE, FALSE, 0);
 
+	string = g_strdup_printf ("<b>%s</b>", _("Temporary files"));
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
-			    brasero_utils_pack_properties (_("<b>Temporary files</b>"),
+			    brasero_utils_pack_properties (string,
 							   box,
 							   priv->tmpdir,
 							   NULL),
 			    FALSE,
 			    FALSE, 0);
+	g_free (string);
 
 	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (priv->tmpdir),
 				       g_get_tmp_dir ());
 
-	g_signal_connect (priv->tmpdir,
-			  "file-set",
-			  G_CALLBACK (brasero_drive_properties_tmpdir_changed_cb),
-			  object);
-
 	gtk_widget_show_all (GTK_DIALOG (object)->vbox);
+
+	g_signal_connect (priv->tmpdir,
+			  "selection-changed",
+			  G_CALLBACK (brasero_drive_properties_tmpdir_changed),
+			  object);
+	g_signal_connect (object,
+			  "response",
+			  G_CALLBACK (brasero_drive_properties_response),
+			  NULL);
 }
 
 static void
 brasero_drive_properties_finalize (GObject *object)
 {
-	BraseroDrivePropertiesPrivate *priv;
-
-	priv = BRASERO_DRIVE_PROPERTIES_PRIVATE (object);
-
-	if (priv->previous_path) {
-		g_free (priv->previous_path);
-		priv->previous_path = NULL;
-	}
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (brasero_drive_properties_parent_class)->finalize (object);
 }
 
 static void
 brasero_drive_properties_class_init (BraseroDrivePropertiesClass *klass)
 {
-	GObjectClass* object_class = G_OBJECT_CLASS (klass);
-	parent_class = GTK_DIALOG_CLASS (g_type_class_peek_parent (klass));
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	g_type_class_add_private (klass, sizeof (BraseroDrivePropertiesPrivate));
 
