@@ -34,14 +34,18 @@
 
 #include <gio/gio.h>
 
+#include <gtk/gtk.h>
+
 #ifdef BUILD_PLAYLIST
 #include <totem-pl-parser.h>
 #endif
 
 #include "burn-basics.h"
 #include "burn-debug.h"
-#include "brasero-utils.h"
+#include "burn-volume.h"
 
+#include "brasero-app.h"
+#include "brasero-utils.h"
 #include "brasero-io.h"
 #include "brasero-metadata.h"
 #include "brasero-async-task-manager.h"
@@ -51,11 +55,15 @@ struct _BraseroIOPrivate
 {
 	GMutex *lock;
 
+	GSList *mounted;
+
 	/* used for returning results */
 	GSList *results;
 	gint results_id;
 
 	/* used for metadata */
+	GMutex *lock_metadata;
+
 	GSList *metadatas;
 	GSList *metadata_running;
 
@@ -126,6 +134,7 @@ struct _BraseroIOJobProgress {
 
 G_DEFINE_TYPE (BraseroIO, brasero_io, BRASERO_TYPE_ASYNC_TASK_MANAGER);
 
+
 /**
  * That's the structure to pass the progress on
  */
@@ -141,14 +150,19 @@ brasero_io_job_progress_report_cb (gpointer callback_data)
 	g_mutex_lock (priv->lock);
 	for (iter = priv->progress; iter; iter = iter->next) {
 		BraseroIOJobProgress *progress;
+		gpointer callback_data;
 
 		progress = iter->data;
 
+		callback_data = progress->job->callback_data?
+				progress->job->callback_data->callback_data:
+				NULL;
+
 		/* update our progress */
 		progress->progress (progress->job, progress);
 		progress->job->base->progress (progress->job->base->object,
 					       progress,
-					       progress->job->callback_data);
+					       callback_data);
 	}
 	g_mutex_unlock (priv->lock);
 
@@ -323,6 +337,7 @@ brasero_io_return_result_idle (gpointer callback_data)
 						       FALSE);
 		brasero_io_job_result_free (result);
 	}
+
 	return TRUE;
 }
 
@@ -440,9 +455,11 @@ brasero_io_job_free (BraseroIO *self,
 		 * add a dummy result to destroy callback_data. */
 		if (g_atomic_int_dec_and_test (&job->callback_data->ref)) {
 			if (cancelled) {
-				job->base->destroy (job->base->object,
-						    TRUE,
-						    job->callback_data);
+				if (job->base->destroy)
+					job->base->destroy (job->base->object,
+							    TRUE,
+							    job->callback_data->callback_data);
+
 				g_free (job->callback_data);
 			}
 			else
@@ -477,6 +494,83 @@ brasero_io_job_destroy (BraseroAsyncTaskManager *manager,
 	brasero_io_job_free (BRASERO_IO (manager), cancelled, job);
 }
 
+/**
+ * That's when we need to mount a remote volume
+ */
+
+struct _BraseroIOMount {
+	GError *error;
+	gboolean result;
+	gboolean finished;
+};
+typedef struct _BraseroIOMount BraseroIOMount;
+
+static void
+brasero_io_mount_enclosing_volume_cb (GObject *source,
+				      GAsyncResult *result,
+				      gpointer callback_data)
+{
+	BraseroIOMount *mount = callback_data;
+
+	BRASERO_BURN_LOG ("Volume mounting operation result");
+	mount->result = g_file_mount_enclosing_volume_finish (G_FILE (source),
+							      result,
+							      &mount->error);
+	mount->finished = TRUE;
+}
+
+static gboolean
+brasero_io_mount_enclosing_volume (BraseroIO *self,
+				   GFile *file,
+				   GCancellable *cancel,
+				   GError **error)
+{
+	GMount *mounted;
+	GMountOperation *operation;
+	BraseroIOMount mount = { NULL, };
+
+	operation = gtk_mount_operation_new (GTK_WINDOW (brasero_app_get_default ()));
+	g_file_mount_enclosing_volume (file,
+				       G_MOUNT_MOUNT_NONE,
+				       operation,
+				       cancel,
+				       brasero_io_mount_enclosing_volume_cb,
+				       &mount);
+
+	/* sleep and wait operation end */
+	while (!mount.finished && !g_cancellable_is_cancelled (cancel))
+		sleep (1);
+
+	mounted = g_file_find_enclosing_mount (file, cancel, NULL);
+	if (mounted) {
+		BraseroIOPrivate *priv;
+
+		priv = BRASERO_IO_PRIVATE (self);
+
+		/* Keep these for later to unmount them */
+		if (mount.result) {
+			g_mutex_lock (priv->lock);
+			priv->mounted = g_slist_prepend (priv->mounted, mounted);
+			g_mutex_unlock (priv->lock);
+		}
+		else
+			g_object_unref (mounted);
+	}
+
+	if (!mounted
+	&&   mount.error
+	&&  !g_cancellable_is_cancelled (cancel))
+		g_propagate_error (error, mount.error);
+	else if (mount.error)
+		g_error_free (mount.error);
+
+	BRASERO_BURN_LOG ("Parent volume is %s",
+			  (mounted != NULL && !g_cancellable_is_cancelled (cancel))?
+			  "mounted":"not mounted");
+
+	return (mounted != NULL && !g_cancellable_is_cancelled (cancel));
+}
+
 /**
  * This part deals with symlinks, that allows to get unique filenames by
  * replacing any parent symlink by its target and check for recursive
@@ -584,12 +678,12 @@ brasero_io_get_uri_from_path (GFile *file,
 
 static gboolean
 brasero_io_check_symlink_target (GFile *parent,
-				 GFileInfo *info,
-				 const gchar *escaped_uri)
+				 GFileInfo *info)
 {
 	const gchar *target;
 	gchar *target_uri;
 	guint size;
+	gchar *uri;
 
 	target = g_file_info_get_symlink_target (info);
     	if (!target)
@@ -602,11 +696,15 @@ brasero_io_check_symlink_target (GFile *parent,
 	/* we check for circular dependency here :
 	 * if the target is one of the parent of symlink */
 	size = strlen (target_uri);
-	if (!strncmp (target_uri, escaped_uri, size)
-	&& (*(escaped_uri + size) == '/' || *(escaped_uri + size) == '\0')) {
+	uri = g_file_get_uri (parent);
+
+	if (!strncmp (target_uri, uri, size)
+	&& (*(uri + size) == '/' || *(uri + size) == '\0')) {
 		g_free (target_uri);
+		g_free (uri);
 		return FALSE;
 	}
+	g_free (uri);
 
 	g_file_info_set_symlink_target (info, target_uri);
 	g_free (target_uri);
@@ -673,11 +771,145 @@ brasero_io_set_metadata_attributes (GFileInfo *info,
 	g_file_info_set_attribute_boolean (info, BRASERO_IO_IS_SEEKABLE, metadata->is_seekable);
 
 	if (metadata->snapshot)
-		g_file_info_set_attribute_object (info, BRASERO_IO_SNAPSHOT, G_OBJECT (metadata->snapshot));
+		g_file_info_set_attribute_object (info, BRASERO_IO_THUMBNAIL, G_OBJECT (metadata->snapshot));
 
 	/* FIXME: what about silences */
 }
 
+static BraseroMetadata *
+brasero_io_find_metadata (BraseroIO *self,
+			  GCancellable *cancel,
+			  const gchar *uri,
+			  BraseroMetadataFlag flags,
+			  GError **error)
+{
+	GSList *iter;
+	BraseroIOPrivate *priv;
+	BraseroMetadata *metadata;
+
+	priv = BRASERO_IO_PRIVATE (self);
+
+	BRASERO_BURN_LOG ("Retrieving available metadata %s", uri);
+
+	/* First see if a metadata is running with the same uri and the same
+	 * flags as us. In this case, acquire the lock and wait for the lock
+	 * to become available which will mean that it has finished
+	 * NOTE: since we will hold the lock another thread waiting to get 
+	 * an available metadata won't be able to have this one. */
+	for (iter = priv->metadata_running; iter; iter = iter->next) {
+		const gchar *metadata_uri;
+		BraseroMetadataFlag metadata_flags;
+
+		metadata = iter->data;
+		metadata_uri = brasero_metadata_get_uri (metadata);
+		if (!metadata_uri) {
+			/* It could a metadata that was running but failed to
+			 * retrieve anything and is waiting to be inserted back
+			 * in the available list. Ignore it. */
+			continue;
+		}
+
+		metadata_flags = brasero_metadata_get_flags (metadata);
+
+		if (((flags & metadata_flags) == flags)
+		&&  !strcmp (uri, metadata_uri)) {
+			/* Found one: release the IO lock to let other threads
+			 * do what they need to do then lock the metadata lock
+			 * Let the thread that got the lock first move it back
+			 * to waiting queue */
+			BRASERO_BURN_LOG ("Already ongoing search for %s", uri);
+			brasero_metadata_increase_listener_number (metadata);
+			return metadata;
+		}
+	}
+
+	/* Grab an available metadata (NOTE: there should always be at least one
+	 * since we run 2 threads at max and have two metadatas available) */
+	while (!priv->metadatas) {
+		if (g_cancellable_is_cancelled (cancel))
+			return NULL;
+
+		g_mutex_unlock (priv->lock_metadata);
+		g_usleep (250);
+		g_mutex_lock (priv->lock_metadata);
+	}
+
+	/* One metadata is finally available */
+	metadata = priv->metadatas->data;
+
+	/* Try to set it up for running */
+	if (!brasero_metadata_set_uri (metadata, flags, uri, error))
+		return NULL;
+
+	/* The metadata is ready for running put it in right queue */
+	brasero_metadata_increase_listener_number (metadata);
+	priv->metadatas = g_slist_remove (priv->metadatas, metadata);
+	priv->metadata_running = g_slist_prepend (priv->metadata_running, metadata);
+
+	return metadata;
+}
+
+static gboolean
+brasero_io_wait_for_metadata (BraseroIO *self,
+			      GCancellable *cancel,
+			      GFileInfo *info,
+			      BraseroMetadata *metadata,
+			      BraseroMetadataInfo *meta_info)
+{
+	gboolean result;
+	gboolean is_last;
+	BraseroIOPrivate *priv;
+
+	priv = BRASERO_IO_PRIVATE (self);
+
+	brasero_metadata_wait (metadata, cancel);
+	g_mutex_lock (priv->lock_metadata);
+
+	is_last = brasero_metadata_decrease_listener_number (metadata);
+
+	if (!g_cancellable_is_cancelled (cancel))
+		result = brasero_metadata_get_result (metadata, meta_info, NULL);
+	else
+		result = FALSE;
+
+	/* Only the last thread waiting for the result will put metadata back
+	 * into the available queue and cache the results. */
+	if (!is_last) {
+		g_mutex_unlock (priv->lock_metadata);
+		return result;
+	}
+
+	if (result) {
+		/* see if we should add it to the buffer */
+		if (meta_info->has_audio || meta_info->has_video) {
+			BraseroIOMetadataCached *cached;
+
+			cached = g_new0 (BraseroIOMetadataCached, 1);
+			cached->last_modified = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
+
+			cached->info = g_new0 (BraseroMetadataInfo, 1);
+			brasero_metadata_get_result (metadata, cached->info, NULL);
+
+			g_queue_push_head (priv->meta_buffer, cached);
+			if (g_queue_get_length (priv->meta_buffer) > MAX_BUFFERED_META) {
+				cached = g_queue_pop_tail (priv->meta_buffer);
+				brasero_io_metadata_cached_free (cached);
+			}
+		}
+	}
+
+	/* Make sure it is stopped */
+	BRASERO_BURN_LOG ("Stopping metadata information retrieval (%p)", metadata);
+	brasero_metadata_cancel (metadata);
+
+	priv->metadata_running = g_slist_remove (priv->metadata_running, metadata);
+	priv->metadatas = g_slist_append (priv->metadatas, metadata);
+
+	g_mutex_unlock (priv->lock_metadata);
+
+	return result;
+}
+
 static gboolean
 brasero_io_get_metadata_info (BraseroIO *self,
 			      GCancellable *cancel,
@@ -689,8 +921,6 @@ brasero_io_get_metadata_info (BraseroIO *self,
 	BraseroMetadata *metadata = NULL;
 	BraseroIOPrivate *priv;
 	const gchar *mime;
-	gboolean result;
-	GSList *iter;
 	GList *node;
 
 	if (g_cancellable_is_cancelled (cancel))
@@ -707,40 +937,9 @@ brasero_io_get_metadata_info (BraseroIO *self,
 	||  !strcmp (mime, "application/octet-stream")))
 		return FALSE;
 
-	g_mutex_lock (priv->lock);
+	BRASERO_BURN_LOG ("Retrieving metadata info");
+	g_mutex_lock (priv->lock_metadata);
 
-	/* First see if a metadata is running with the same uri and the same
-	 * flags as us. In this case, acquire the lock and wait for the lock
-	 * to become available which will mean that it has finished
-	 * NOTE: since we will hold the lock another thread waiting to get 
-	 * an available metadata won't be able to have this one. */
-	for (iter = priv->metadata_running; iter; iter = iter->next) {
-		const gchar *metadata_uri;
-		BraseroMetadata *metadata_iter;
-		BraseroMetadataFlag metadata_flags;
-
-		metadata_iter = iter->data;
-		metadata_uri = brasero_metadata_get_uri (metadata_iter);
-		metadata_flags = brasero_metadata_get_flags (metadata_iter);
-
-		if (((flags & metadata_flags) == flags)
-		&&  !strcmp (uri, metadata_uri)) {
-			/* Found one: release the IO lock to let other threads
-			 * do what they need to do then lock the metadata lock
-			 * Let the thread that got the lock first move it back
-			 * to waiting queue */
-			BRASERO_BURN_LOG ("Already ongoing search for %s", uri);
-
-			metadata = metadata_iter;
-
-			g_mutex_unlock (priv->lock);
-			brasero_metadata_lock (metadata);
-			result = brasero_metadata_set_info (metadata, meta_info);
-			brasero_metadata_unlock (metadata);
-
-			return result;
-		}
-	}
 	/* Seek in the buffer if we have already explored these metadata. Check 
 	 * the info last modified time in case a result should be updated. */
 	node = g_queue_find_custom (priv->meta_buffer,
@@ -753,96 +952,42 @@ brasero_io_get_metadata_info (BraseroIO *self,
 		cached = node->data;
 		last_modified = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
 		if (last_modified == cached->last_modified) {
-			if (flags & BRASERO_METADATA_FLAG_SNAPHOT) {
+			if (flags & BRASERO_METADATA_FLAG_THUMBNAIL) {
 				/* If there isn't any snapshot retry */
 				if (cached->info->snapshot) {
 					brasero_metadata_info_copy (meta_info, cached->info);
-					g_mutex_unlock (priv->lock);
+					g_mutex_unlock (priv->lock_metadata);
 					return TRUE;
 				}
 			}
 			else {
 				brasero_metadata_info_copy (meta_info, cached->info);
-				g_mutex_unlock (priv->lock);
+				g_mutex_unlock (priv->lock_metadata);
 				return TRUE;
 			}
 		}
 
-		/* remove it from the queue => no same URI twice */
+		/* Found the same URI but it didn't have all required flags so
+		 * we'll get another metadata information; Remove it from the
+		 * queue => no same URI twice */
 		g_queue_remove (priv->meta_buffer, cached);
 		brasero_io_metadata_cached_free (cached);
 
 		BRASERO_BURN_LOG ("Updating cache information for %s", uri);
 	}
 
-	/* grab an available metadata (NOTE: there should always be at least one
-	 * since we run 2 threads at max and have two metadatas available) */
-	do {
+	/* Find a metadata */
+	metadata = brasero_io_find_metadata (self, cancel, uri, flags, NULL);
+	g_mutex_unlock (priv->lock_metadata);
 
-		if (g_cancellable_is_cancelled (cancel)) {
-			g_mutex_unlock (priv->lock);
-			return FALSE;
-		}
+	if (!metadata)
+		return FALSE;
 
-		for (iter = priv->metadatas; iter; iter = iter->next) {
-			BraseroMetadata *metadata_iter;
-
-			metadata_iter = iter->data;
-			if (brasero_metadata_try_lock (metadata_iter)) {
-				metadata = priv->metadatas->data;
-				priv->metadatas = g_slist_remove (priv->metadatas, metadata);
-				priv->metadata_running = g_slist_prepend (priv->metadata_running, metadata);
-				break;
-			}
-		}
-
-		g_mutex_unlock (priv->lock);
-		g_usleep (250);
-		g_mutex_lock (priv->lock);
-
-	} while (!metadata);
-
-	g_mutex_unlock (priv->lock);
-
-	result = brasero_metadata_get_info_wait (metadata,
-						 cancel,
-						 uri,
-						 flags,
-						 NULL);
-	brasero_metadata_set_info (metadata, meta_info);
-
-	g_mutex_lock (priv->lock);
-
-	/* release the lock on the metadata in case another thread is waiting 
-	 * for this search result. That way that thread will be able to wake
-	 * up. */
-	brasero_metadata_unlock (metadata);
-
-	if (result) {
-		/* see if we should add it to the buffer */
-		if (meta_info->has_audio || meta_info->has_video) {
-			BraseroIOMetadataCached *cached;
-
-			cached = g_new0 (BraseroIOMetadataCached, 1);
-			cached->last_modified = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
-
-			cached->info = g_new0 (BraseroMetadataInfo, 1);
-			brasero_metadata_set_info (metadata, cached->info);
-
-			g_queue_push_head (priv->meta_buffer, cached);
-			if (g_queue_get_length (priv->meta_buffer) > MAX_BUFFERED_META) {
-				cached = g_queue_pop_tail (priv->meta_buffer);
-				brasero_io_metadata_cached_free (cached);
-			}
-		}
-	}
-
-	priv->metadata_running = g_slist_remove (priv->metadata_running, metadata);
-	priv->metadatas = g_slist_prepend (priv->metadatas, metadata);
-
-	g_mutex_unlock (priv->lock);
-
-	return result;
+	return brasero_io_wait_for_metadata (self,
+					     cancel,
+					     info,
+					     metadata,
+					     meta_info);
 }
 
 /**
@@ -852,7 +997,7 @@ brasero_io_get_metadata_info (BraseroIO *self,
 static GFileInfo *
 brasero_io_get_file_info_thread_real (BraseroAsyncTaskManager *manager,
 				      GCancellable *cancel,
-				      const gchar *uri,
+				      GFile *file,
 				      BraseroIOFlags options,
 				      GError **error)
 {
@@ -861,32 +1006,59 @@ brasero_io_get_file_info_thread_real (BraseroAsyncTaskManager *manager,
 				  G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK ","
 				  G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET ","
 				  G_FILE_ATTRIBUTE_STANDARD_TYPE};
+	GError *local_error = NULL;
+	gboolean should_thumbnail;
 	GFileInfo *info;
-	GFile *file;
 
 	if (g_cancellable_is_cancelled (cancel))
-		return BRASERO_ASYNC_TASK_FINISHED;
-	
+		return NULL;
+
 	if (options & BRASERO_IO_INFO_PERM)
 		strcat (attributes, "," G_FILE_ATTRIBUTE_ACCESS_CAN_READ);
 	if (options & BRASERO_IO_INFO_MIME)
 		strcat (attributes, "," G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
 	if (options & BRASERO_IO_INFO_ICON)
 		strcat (attributes, "," G_FILE_ATTRIBUTE_STANDARD_ICON);
+	if (options & BRASERO_IO_INFO_METADATA_THUMBNAIL)
+		strcat (attributes, "," G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
 
 	/* if retrieving metadata we need this one to check if a possible result
 	 * in cache should be updated or used */
 	if (options & BRASERO_IO_INFO_METADATA)
 		strcat (attributes, "," G_FILE_ATTRIBUTE_STANDARD_SIZE);
 
-	file = g_file_new_for_uri (uri);
 	info = g_file_query_info (file,
 				  attributes,
-				  G_FILE_QUERY_INFO_NONE,	/* follow symlinks */
+				  (options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 				  cancel,
-				  error);
+				  &local_error);
 	if (!info) {
-		g_object_unref (file);
+		if (local_error && local_error->code == G_IO_ERROR_NOT_MOUNTED) {
+			gboolean res;
+
+			BRASERO_BURN_LOG ("Starting to mount parent volume");
+			g_error_free (local_error);
+			local_error = NULL;
+
+			/* try to mount whatever has to be mounted */
+			/* NOTE: of course, we block a thread but one advantage
+			 * is that we won't have many queries to mount the same
+			 * remote volume at the same time. */
+			res = brasero_io_mount_enclosing_volume (BRASERO_IO (manager),
+								 file,
+								 cancel,
+								 error);
+			if (!res)
+				return NULL;
+
+			return brasero_io_get_file_info_thread_real (manager,
+								     cancel,
+								     file,
+								     options,
+								     error);
+		}
+
+		g_propagate_error (error, local_error);
 		return NULL;
 	}
 
@@ -894,11 +1066,11 @@ brasero_io_get_file_info_thread_real (BraseroAsyncTaskManager *manager,
 		GFile *parent;
 
 		parent = g_file_get_parent (file);
-		if (!brasero_io_check_symlink_target (parent, info, uri)) {
+		if (!brasero_io_check_symlink_target (parent, info)) {
 			g_set_error (error,
 				     BRASERO_ERROR,
 				     BRASERO_ERROR_SYMLINK_LOOP,
-				     _("recursive symbolic link"));
+				     _("Recursive symbolic link"));
 
 			g_object_unref (info);
 			g_object_unref (file);
@@ -907,22 +1079,50 @@ brasero_io_get_file_info_thread_real (BraseroAsyncTaskManager *manager,
 		}
 		g_object_unref (parent);
 	}
-	g_object_unref (file);
+
+	should_thumbnail = FALSE;
+	if (options & BRASERO_IO_INFO_METADATA_THUMBNAIL) {
+		const gchar *path;
+
+		path = g_file_info_get_attribute_byte_string (info, G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
+		if (path) {
+			GdkPixbuf *pixbuf;
+
+			pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+			if (pixbuf) {
+				g_file_info_set_attribute_object (info,
+								  BRASERO_IO_THUMBNAIL,
+								  G_OBJECT (pixbuf));
+				g_object_unref (pixbuf);
+			}
+			else
+				should_thumbnail = TRUE;
+		}
+		else if (!g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_THUMBNAILING_FAILED))
+			should_thumbnail = TRUE;
+	}
 
 	/* see if we are supposed to get metadata for this file (provided it's
 	 * an audio file of course). */
-	if (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY
-	&&  options & BRASERO_IO_INFO_METADATA) {
+	if ((g_file_info_get_file_type (info) == G_FILE_TYPE_REGULAR
+	||   g_file_info_get_file_type (info) == G_FILE_TYPE_SYMBOLIC_LINK)
+	&&  (options & BRASERO_IO_INFO_METADATA)) {
 		BraseroMetadataInfo metadata = { NULL };
+		BraseroMetadataFlag flags;
 		gboolean result;
+		gchar *uri;
 
+		flags = ((options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0)|
+			((should_thumbnail) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0);
+
+		uri = g_file_get_uri (file);
 		result = brasero_io_get_metadata_info (BRASERO_IO (manager),
 						       cancel,
 						       uri,
 						       info,
-						       ((options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0) |
-						       ((options & BRASERO_IO_INFO_METADATA_SNAPSHOT) ? BRASERO_METADATA_FLAG_SNAPHOT : 0),
+						       flags,
 						       &metadata);
+		g_free (uri);
 
 		if (result)
 			brasero_io_set_metadata_attributes (info, &metadata);
@@ -942,6 +1142,7 @@ brasero_io_get_file_info_thread (BraseroAsyncTaskManager *manager,
 	gchar *file_uri = NULL;
 	GError *error = NULL;
 	GFileInfo *info;
+	GFile *file;
 
 	if (job->options & BRASERO_IO_INFO_CHECK_PARENT_SYMLINK) {
 		/* If we want to make sure a directory is not added twice we have to make sure
@@ -959,15 +1160,22 @@ brasero_io_get_file_info_thread (BraseroAsyncTaskManager *manager,
 		return BRASERO_ASYNC_TASK_FINISHED;
 	}
 
+	file = g_file_new_for_uri (file_uri?file_uri:job->uri);
 	info = brasero_io_get_file_info_thread_real (manager,
 						     cancel,
-						     file_uri?file_uri:job->uri,
+						     file,
 						     job->options,
 						     &error);
 
+	/* do this to have a very nice URI:
+	 * for example: file://pouet instead of file://../directory/pouet */
+	g_free (file_uri);
+	file_uri = g_file_get_uri (file);
+	g_object_unref (file);
+
 	brasero_io_return_result (BRASERO_IO (manager),
 				  job->base,
-				  file_uri?file_uri:job->uri,
+				  file_uri,
 				  info,
 				  error,
 				  job->callback_data);
@@ -1095,7 +1303,7 @@ brasero_io_parse_playlist_get_uris (const gchar *uri,
 		g_set_error (error,
 			     BRASERO_ERROR,
 			     BRASERO_ERROR_GENERAL,
-			     _("the file doesn't appear to be a playlist"));
+			     _("The file does not appear to be a playlist"));
 
 		return FALSE;
 	}
@@ -1153,6 +1361,7 @@ brasero_io_parse_playlist_thread (BraseroAsyncTaskManager *manager,
 	 * Reverse order of list to get a correct order for entries. */
 	data.uris = g_slist_reverse (data.uris);
 	for (iter = data.uris; iter; iter = iter->next) {
+		GFile *file;
 		gchar *child;
 		GFileInfo *child_info;
 
@@ -1160,11 +1369,13 @@ brasero_io_parse_playlist_thread (BraseroAsyncTaskManager *manager,
 		if (g_cancellable_is_cancelled (cancel))
 			break;
 
+		file = g_file_new_for_uri (child);
 		child_info = brasero_io_get_file_info_thread_real (manager,
 								   cancel,
-								   child,
+								   file,
 								   job->options,
 								   NULL);
+		g_object_unref (file);
 
 		if (!child_info)
 			continue;
@@ -1278,7 +1489,7 @@ brasero_io_get_file_count_process_playlist (BraseroIO *self,
 						       child_uri,
 						       info,
 						       ((data->job.options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0) |
-						       ((data->job.options & BRASERO_IO_INFO_METADATA_SNAPSHOT) ? BRASERO_METADATA_FLAG_SNAPHOT : 0) |
+						       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0) |
 						       BRASERO_METADATA_FLAG_FAST,
 						       &metadata);
 
@@ -1315,7 +1526,7 @@ brasero_io_get_file_count_process_file (BraseroIO *self,
 						       child_uri,
 						       info,
 						       ((data->job.options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0) |
-						       ((data->job.options & BRASERO_IO_INFO_METADATA_SNAPSHOT) ? BRASERO_METADATA_FLAG_SNAPHOT : 0),
+						       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0),
 						       &metadata);
 		if (result)
 			data->total_b += metadata.len;
@@ -1374,7 +1585,7 @@ brasero_io_get_file_count_process_directory (BraseroIO *self,
 
 	enumerator = g_file_enumerate_children (file,
 						attributes,
-						G_FILE_QUERY_INFO_NONE,	/* follow symlinks */
+						(data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 						cancel,
 						NULL);
 	if (!enumerator) {
@@ -1402,12 +1613,15 @@ brasero_io_get_file_count_process_directory (BraseroIO *self,
 
 		child = g_file_get_child (file, g_file_info_get_name (info));
 
-		if (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY) {
+		if (g_file_info_get_file_type (info) == G_FILE_TYPE_REGULAR
+		||  g_file_info_get_file_type (info) == G_FILE_TYPE_SYMBOLIC_LINK) {
 			brasero_io_get_file_count_process_file (self, cancel, data, child, info);
 			g_object_unref (child);
 		}
-		else
+		else if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY)
 			data->children = g_slist_prepend (data->children, child);
+		else
+			g_object_unref (child);
 
 		g_object_unref (info);
 	}
@@ -1436,7 +1650,7 @@ brasero_io_get_file_count_start (BraseroIO *self,
 	file = g_file_new_for_uri (uri);
 	info = g_file_query_info (file,
 				  attributes,
-				  G_FILE_QUERY_INFO_NONE, /* follow symlinks */
+				  (data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 				  cancel,
 				  NULL);
 
@@ -1447,12 +1661,17 @@ brasero_io_get_file_count_start (BraseroIO *self,
 		return FALSE;
 	}
 
-	if (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY) {
+	if (g_file_info_get_file_type (info) == G_FILE_TYPE_REGULAR
+	||  g_file_info_get_file_type (info) == G_FILE_TYPE_SYMBOLIC_LINK) {
 		brasero_io_get_file_count_process_file (self, cancel, data, file, info);
 		g_object_unref (file);
 	}
-	else if (data->job.options & BRASERO_IO_INFO_RECURSIVE)
-		data->children = g_slist_prepend (data->children, file);
+	else if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY) {
+		if (data->job.options & BRASERO_IO_INFO_RECURSIVE)
+			data->children = g_slist_prepend (data->children, file);
+		else
+			g_object_unref (file);
+	}
 	else
 		g_object_unref (file);
 
@@ -1616,7 +1835,7 @@ brasero_io_load_directory_playlist (BraseroIO *self,
 						       child_uri,
 						       info,
 						       ((data->job.options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0) |
-						       ((data->job.options & BRASERO_IO_INFO_METADATA_SNAPSHOT) ? BRASERO_METADATA_FLAG_SNAPHOT : 0) |
+						       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0) |
 						       BRASERO_METADATA_FLAG_FAST,
 						       &metadata);
 
@@ -1680,7 +1899,7 @@ brasero_io_load_directory_thread (BraseroAsyncTaskManager *manager,
 
 	enumerator = g_file_enumerate_children (file,
 						attributes,
-						G_FILE_QUERY_INFO_NONE,		/* follow symlinks */
+						(data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 						cancel,
 						&error);
 
@@ -1729,10 +1948,10 @@ brasero_io_load_directory_thread (BraseroAsyncTaskManager *manager,
 
 		/* special case for symlinks */
 		if (g_file_info_get_is_symlink (info)) {
-			if (!brasero_io_check_symlink_target (file, info, child_uri)) {
+			if (!brasero_io_check_symlink_target (file, info)) {
 				error = g_error_new (BRASERO_ERROR,
 						     BRASERO_ERROR_SYMLINK_LOOP,
-						     _("recursive symbolic link"));
+						     _("Recursive symbolic link"));
 
 				/* since we checked for the existence of the file
 				 * an error means a looping symbolic link */
@@ -1777,7 +1996,7 @@ brasero_io_load_directory_thread (BraseroAsyncTaskManager *manager,
 							       child_uri,
 							       info,
 							       ((data->job.options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0) |
-							       ((data->job.options & BRASERO_IO_INFO_METADATA_SNAPSHOT) ? BRASERO_METADATA_FLAG_SNAPHOT : 0),
+							       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0),
 							       &metadata);
 
 			if (result)
@@ -1856,6 +2075,129 @@ brasero_io_load_directory (BraseroIO *self,
 	brasero_io_push_job (self, BRASERO_IO_JOB (data), &contents_type);
 }
 
+/**
+ * to evaluate the contents of a medium or image async
+ */
+struct _BraseroIOImageContentsData {
+	BraseroIOJob job;
+	gchar *dev_image;
+
+	gint64 session_block;
+	gint64 block;
+};
+typedef struct _BraseroIOImageContentsData BraseroIOImageContentsData;
+
+static void
+brasero_io_image_directory_contents_destroy (BraseroAsyncTaskManager *manager,
+					     gboolean cancelled,
+					     gpointer callback_data)
+{
+	BraseroIOImageContentsData *data = callback_data;
+
+	g_free (data->dev_image);
+	brasero_io_job_free (BRASERO_IO (manager), cancelled, BRASERO_IO_JOB (data));
+}
+
+static BraseroAsyncTaskResult
+brasero_io_image_directory_contents_thread (BraseroAsyncTaskManager *manager,
+					    GCancellable *cancel,
+					    gpointer callback_data)
+{
+	BraseroIOImageContentsData *data = callback_data;
+	BraseroDeviceHandle *handle;
+	GList *children, *iter;
+	GError *error = NULL;
+	BraseroVolSrc *vol;
+
+	handle = brasero_device_handle_open (data->job.uri, FALSE, NULL);
+	vol = brasero_volume_source_open_device_handle (handle, &error);
+	if (!vol) {
+		brasero_device_handle_close (handle);
+		brasero_io_return_result (BRASERO_IO (manager),
+					  data->job.base,
+					  data->job.uri,
+					  NULL,
+					  error,
+					  data->job.callback_data);
+		return BRASERO_ASYNC_TASK_FINISHED;
+	}
+
+	children = brasero_volume_load_directory_contents (vol,
+							   data->session_block,
+							   data->block,
+							   &error);
+	brasero_volume_source_close (vol);
+	brasero_device_handle_close (handle);
+
+	for (iter = children; iter; iter = iter->next) {
+		BraseroVolFile *file;
+		GFileInfo *info;
+
+		file = iter->data;
+
+		info = g_file_info_new ();
+		g_file_info_set_file_type (info, file->isdir? G_FILE_TYPE_DIRECTORY:G_FILE_TYPE_REGULAR);
+		g_file_info_set_name (info, BRASERO_VOLUME_FILE_NAME (file));
+
+		if (file->isdir)
+			g_file_info_set_attribute_int64 (info,
+							 BRASERO_IO_DIR_CONTENTS_ADDR,
+							 file->specific.dir.address);
+		else
+			g_file_info_set_size (info, BRASERO_VOLUME_FILE_SIZE (file));
+
+		brasero_io_return_result (BRASERO_IO (manager),
+					  data->job.base,
+					  data->job.uri,
+					  info,
+					  NULL,
+					  data->job.callback_data);
+	}
+
+	g_list_foreach (children, (GFunc) brasero_volume_file_free, NULL);
+	g_list_free (children);
+
+	return BRASERO_ASYNC_TASK_FINISHED;
+}
+
+static const BraseroAsyncTaskType image_contents_type = {
+	brasero_io_image_directory_contents_thread,
+	brasero_io_image_directory_contents_destroy
+};
+
+void
+brasero_io_load_image_directory (BraseroIO *self,
+				 const gchar *dev_image,
+				 gint64 session_block,
+				 gint64 block,
+				 const BraseroIOJobBase *base,
+				 BraseroIOFlags options,
+				 gpointer user_data)
+{
+	BraseroIOImageContentsData *data;
+	BraseroIOResultCallbackData *callback_data = NULL;
+
+	if (user_data) {
+		callback_data = g_new0 (BraseroIOResultCallbackData, 1);
+		callback_data->callback_data = user_data;
+	}
+
+	data = g_new0 (BraseroIOImageContentsData, 1);
+	data->block = block;
+	data->session_block = session_block;
+
+	brasero_io_set_job (BRASERO_IO_JOB (data),
+			    base,
+			    dev_image,
+			    options,
+			    callback_data);
+
+	brasero_io_push_job (self,
+			     BRASERO_IO_JOB (data),
+			     &image_contents_type);
+
+}
+					 
 /**
  * That's for file transfer
  */
@@ -1968,7 +2310,7 @@ brasero_io_xfer_recursive_thread (BraseroIOXferData *data,
 	enumerator = g_file_enumerate_children (src,
 						G_FILE_ATTRIBUTE_STANDARD_TYPE ","
 						G_FILE_ATTRIBUTE_STANDARD_NAME,
-						G_FILE_QUERY_INFO_NONE,	/* follow symlinks */
+						G_FILE_QUERY_INFO_NONE,	/* follow symlinks by default */
 						cancel,
 						error);
 	if (!enumerator)
@@ -2040,7 +2382,7 @@ brasero_io_xfer_start (BraseroIO *self,
 	data->info = g_file_query_info (file,
 					G_FILE_ATTRIBUTE_STANDARD_TYPE","
 					G_FILE_ATTRIBUTE_STANDARD_SIZE,
-					G_FILE_QUERY_INFO_NONE, /* follow symlinks */
+					G_FILE_QUERY_INFO_NONE,	/* follow symlinks by default*/
 					cancel,
 					error);
 	if (!data->info || error) {
@@ -2055,22 +2397,25 @@ brasero_io_xfer_start (BraseroIO *self,
 	/* see if we should explore it beforehand to report progress */
 	if (data->count.job.base->progress) {
 		data->count.files_num = 1;
-		if (g_file_info_get_file_type (data->info) != G_FILE_TYPE_DIRECTORY)
+		if (g_file_info_get_file_type (data->info) == G_FILE_TYPE_REGULAR
+		||  g_file_info_get_file_type (data->info) == G_FILE_TYPE_SYMBOLIC_LINK)
 			brasero_io_get_file_count_process_file (self, cancel, &data->count, file, data->info);
-		else
+		else if (g_file_info_get_file_type (data->info) == G_FILE_TYPE_DIRECTORY)
 			brasero_io_get_file_count_process_directory (self, cancel, &data->count);
 	}
 
 	/* start the downloading */
 	if (g_file_info_get_file_type (data->info) == G_FILE_TYPE_DIRECTORY) {
 		if (g_mkdir_with_parents (data->dest_path, 700)) {
+                        int errsv = errno;
+
 			g_object_unref (file);
 
 			g_set_error (error,
 				     BRASERO_ERROR,
 				     BRASERO_ERROR_GENERAL,
-				     _("a directory couldn't be created (%s)"),
-				     strerror (errno));
+				     _("A directory could not be created (%s)"),
+				     g_strerror (errsv));
 			return FALSE;
 		}
 
@@ -2081,7 +2426,8 @@ brasero_io_xfer_start (BraseroIO *self,
 							  data->dest_path,
 							  NULL);
 	}
-	else
+	else if (g_file_info_get_file_type (data->info) == G_FILE_TYPE_REGULAR
+	     ||  g_file_info_get_file_type (data->info) == G_FILE_TYPE_SYMBOLIC_LINK)
 		result = brasero_io_xfer_file_thread (data,
 						      cancel,
 						      file,
@@ -2287,7 +2633,7 @@ brasero_io_cancel_tasks_by_data_cb (BraseroAsyncTaskManager *manager,
 {
 	BraseroIOJob *job = callback_data;
 
-	if (job->callback_data != user_data)
+	if (job->callback_data && job->callback_data->callback_data != user_data)
 		return FALSE;
 
 	return TRUE;
@@ -2343,7 +2689,10 @@ brasero_io_compare_unprocessed_task (BraseroAsyncTaskManager *manager,
 	if (job->base == data->base)
 		return FALSE;
 
-	return data->func (job->callback_data, data->user_data);
+	if (!job->callback_data)
+		return FALSE;
+
+	return data->func (job->callback_data->callback_data, data->user_data);
 }
 
 void
@@ -2389,6 +2738,7 @@ brasero_io_init (BraseroIO *object)
 	priv = BRASERO_IO_PRIVATE (object);
 
 	priv->lock = g_mutex_new ();
+	priv->lock_metadata = g_mutex_new ();
 
 	priv->meta_buffer = g_queue_new ();
 
@@ -2407,11 +2757,6 @@ brasero_io_free_async_queue (BraseroAsyncTaskManager *manager,
 {
 	BraseroIOJob *job = callback_data;
 
-	if (job->base->destroy)
-		job->base->destroy (job->base->object,
-				    TRUE,
-				    job->callback_data);
-
 	brasero_io_job_free (BRASERO_IO (manager), TRUE, job);
 	return TRUE;
 }
@@ -2476,6 +2821,30 @@ brasero_io_finalize (GObject *object)
 		priv->lock = NULL;
 	}
 
+	if (priv->lock_metadata) {
+		g_mutex_free (priv->lock_metadata);
+		priv->lock_metadata = NULL;
+	}
+
+	if (priv->mounted) {
+		GSList *iter;
+
+		/* unmount all volumes we mounted ourselves */
+		for (iter = priv->mounted; iter; iter = iter->next) {
+			GMount *mount;
+
+			mount = iter->data;
+
+			BRASERO_BURN_LOG ("Unmountin volume");
+			g_mount_unmount (mount,
+					 G_MOUNT_UNMOUNT_NONE,
+					 NULL,
+					 NULL,
+					 NULL);
+			g_object_unref (mount);
+		}
+	}
+
 	G_OBJECT_CLASS (brasero_io_parent_class)->finalize (object);
 }
 
