@@ -33,18 +33,7 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkscale.h>
-#include <gtk/gtkrange.h>
-#include <gtk/gtkhscale.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 
 #include <gconf/gconf-client.h>
 
@@ -271,6 +260,11 @@ brasero_player_update_position (BraseroPlayer *player)
 	value = gtk_range_get_value (GTK_RANGE (player->priv->progress));
 	pos_string = brasero_utils_get_time_string (value, FALSE, FALSE);
 
+	/**
+	 * Translators: this is the position being played in the stream. The 
+	 * first %s is the position and the second %s is the whole length of
+	 * the stream. I chose to make that translatable in case some languages
+	 * don't allow the "/" */
 	result = g_strdup_printf (_("%s / %s"), pos_string, len_string);
 	g_free (len_string);
 	g_free (pos_string);
@@ -298,7 +292,7 @@ brasero_player_range_value_changed (GtkRange *range,
 static void
 brasero_player_set_length (BraseroPlayer *player)
 {
-	if (player->priv->progress)
+	if (player->priv->progress && player->priv->end - player->priv->start != 0)
 		gtk_range_set_range (GTK_RANGE (player->priv->progress),
 				     0.0,
 				     (gdouble) player->priv->end - player->priv->start);
@@ -806,7 +800,9 @@ brasero_player_image (BraseroPlayer *player)
 	BRASERO_GET_BASENAME_FOR_DISPLAY (path, name);
 	g_free (path);
 
-	string = g_strdup_printf (_("<span weight=\"bold\">Name:</span>\t %s"), name);
+	string = g_strdup_printf ("<span weight=\"bold\">%s</span>\t %s",
+				  _("Name:"),
+				  name);
 	g_free (name);
 
 	gtk_label_set_markup (GTK_LABEL (player->priv->header), string);
@@ -843,8 +839,7 @@ brasero_player_update_info_real (BraseroPlayer *player,
 
 	}
 	else if (title) {
-		header = g_markup_printf_escaped (_("<span weight=\"bold\">%s</span>\n"),
-						  title);
+		header = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>\n", title);
 		gtk_label_set_ellipsize (GTK_LABEL (player->priv->header),
 					 PANGO_ELLIPSIZE_END);
 	}
@@ -852,8 +847,7 @@ brasero_player_update_info_real (BraseroPlayer *player,
 		gchar *name;
 
 	    	BRASERO_GET_BASENAME_FOR_DISPLAY (player->priv->uri, name);
-		header = g_markup_printf_escaped (_("<span weight=\"bold\">%s</span>\n"),
-						  name);
+		header = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>\n", name);
 		g_free (name);
 		gtk_label_set_ellipsize (GTK_LABEL (player->priv->header),
 					 PANGO_ELLIPSIZE_END);
@@ -871,6 +865,7 @@ brasero_player_metadata_completed (GObject *obj,
 				   gpointer null_data)
 {
 	BraseroPlayer *player = BRASERO_PLAYER (obj);
+	const gchar *mime;
 
 	if (player->priv->pixbuf) {
 		gtk_image_set_from_pixbuf (GTK_IMAGE (player->priv->image_display), NULL);
@@ -889,6 +884,8 @@ brasero_player_metadata_completed (GObject *obj,
 		return;
 	}
 
+	mime = g_file_info_get_content_type (info);
+
 	/* based on the mime type, we try to determine the type of file */
 	if (g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_VIDEO)) {
 		/* video */
@@ -915,8 +912,18 @@ brasero_player_metadata_completed (GObject *obj,
 		else
 			gtk_widget_set_sensitive (player->priv->progress, FALSE);
 	}
-	else if (!strncmp ("image/", g_file_info_get_content_type (info), 6)) {
-		brasero_player_image (player);
+	else if (mime && !strncmp ("image/", mime, 6)) {
+		/* Only do that if the image is < 20 M otherwise that's crap
+		 * FIXME: maybe a sort of error message here? or use thumbnail? */
+		if (g_file_info_get_size (info) > 100000000) {
+			brasero_player_no_multimedia_stream (player);
+			g_signal_emit (player,
+				       brasero_player_signals [ERROR_SIGNAL],
+				       0);
+		}
+		else
+			brasero_player_image (player);
+
 		return;
 	}
 	else {
