@@ -7,7 +7,8 @@
  * Based on gedit code (gedit/gedit-plugin-manager.c) by: 
  * 	- Paolo Maggi <paolo@gnome.org>
  *
- * Brasero is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -143,7 +144,7 @@ about_button_cb (GtkWidget          *button,
 				     brasero_plugin_get_author (plugin));
 
 	dialog = g_object_new (GTK_TYPE_ABOUT_DIALOG,
-			       "program-name", brasero_plugin_get_name (plugin),
+			       "program-name", _(brasero_plugin_get_name (plugin)),
 			       "copyright", copyright,
 			       "authors", authors,
 			       "comments", brasero_plugin_get_description (plugin),
@@ -216,12 +217,16 @@ plugin_manager_ui_view_info_cell_cb (GtkTreeViewColumn *tree_column,
 
 	if (brasero_plugin_get_error (plugin))
 		text = g_markup_printf_escaped ("<b>%s</b>\n%s\n<i>%s</i>",
-						brasero_plugin_get_name (plugin),
+						/* Use the translated name of 
+						 * the plugin. */
+						_(brasero_plugin_get_name (plugin)),
 						brasero_plugin_get_description (plugin),
 						brasero_plugin_get_error (plugin));
 	else
 		text = g_markup_printf_escaped ("<b>%s</b>\n%s",
-						brasero_plugin_get_name (plugin),
+						/* Use the translated name of 
+						 * the plugin. */
+						_(brasero_plugin_get_name (plugin)),
 						brasero_plugin_get_description (plugin));
 
 	g_object_set (G_OBJECT (cell),
@@ -355,9 +360,9 @@ plugin_manager_ui_populate_lists (BraseroPluginManagerUI *pm)
 	for (; plugins; plugins = plugins->next) {
 		plugin = plugins->data;
 
-		if (brasero_burn_caps_plugin_can_burn (caps, plugin) == BRASERO_BURN_OK
-		||  brasero_burn_caps_plugin_can_convert (caps, plugin) == BRASERO_BURN_OK
-		||  brasero_burn_caps_plugin_can_image (caps, plugin) == BRASERO_BURN_OK
+		if (brasero_plugin_can_burn (plugin) == BRASERO_BURN_OK
+		||  brasero_plugin_can_convert (plugin) == BRASERO_BURN_OK
+		||  brasero_plugin_can_image (plugin) == BRASERO_BURN_OK
 		||  brasero_plugin_get_gtype (plugin) == G_TYPE_NONE)
 			continue;
 
@@ -505,8 +510,13 @@ name_search_cb (GtkTreeModel *model,
 	if (!plugin)
 		return FALSE;
 
-	normalized_string = g_utf8_normalize (brasero_plugin_get_name (plugin), -1, G_NORMALIZE_ALL);
-	normalized_key = g_utf8_normalize (key, -1, G_NORMALIZE_ALL);
+	/* Use translated name for the plugin */
+	normalized_string = g_utf8_normalize (_(brasero_plugin_get_name (plugin)),
+					      -1,
+					      G_NORMALIZE_ALL);
+	normalized_key = g_utf8_normalize (key,
+					   -1,
+					   G_NORMALIZE_ALL);
 	case_normalized_string = g_utf8_casefold (normalized_string, -1);
 	case_normalized_key = g_utf8_casefold (normalized_key, -1);
 
@@ -794,8 +804,9 @@ model_name_sort_func (GtkTreeModel *model,
 	gtk_tree_model_get (model, iter1, PLUGIN_COLUMN, &plugin1, -1);
 	gtk_tree_model_get (model, iter2, PLUGIN_COLUMN, &plugin2, -1);
 
-	return g_utf8_collate (brasero_plugin_get_name (plugin1),
-			       brasero_plugin_get_name (plugin2));
+	/* Use the translated name for the plugins */
+	return g_utf8_collate (_(brasero_plugin_get_name (plugin1)),
+			       _(brasero_plugin_get_name (plugin2)));
 }
 
 static void
@@ -901,12 +912,10 @@ plugin_manager_ui_construct_tree (BraseroPluginManagerUI *pm)
 static void 
 brasero_plugin_manager_ui_init (BraseroPluginManagerUI *pm)
 {
-	gchar *markup;
 	GtkWidget *vbox;
 	GtkWidget *hbox;
-	GtkWidget *label;
-	GtkWidget *alignment;
 	GtkWidget *viewport;
+	GtkWidget *alignment;
 	GtkWidget *vbuttonbox;
 	BraseroPluginManager *manager;
 	BraseroPluginManagerUIPrivate *priv;
@@ -916,20 +925,10 @@ brasero_plugin_manager_ui_init (BraseroPluginManagerUI *pm)
 	gtk_box_set_spacing (GTK_BOX (pm), 6);
 	gtk_container_set_border_width (GTK_CONTAINER (pm), 12);
 
-	label = gtk_label_new (NULL);
-	markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
-					  _("Plugins"));
-	gtk_label_set_markup (GTK_LABEL (label), markup);
-	g_free (markup);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	
-	gtk_box_pack_start (GTK_BOX (pm), label, FALSE, TRUE, 0);
-
 	alignment = gtk_alignment_new (0., 0., 1., 1.);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 	gtk_box_pack_start (GTK_BOX (pm), alignment, TRUE, TRUE, 0);
-
+ 	
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (vbox);
 	gtk_container_add (GTK_CONTAINER (alignment), vbox);
