@@ -30,10 +30,9 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
-#include "burn-medium.h"
+#include "brasero-medium.h"
 #include "brasero-project-type-chooser.h"
 
 G_BEGIN_DECLS
@@ -74,10 +73,14 @@ brasero_project_manager_video (BraseroProjectManager *manager,
 			       GSList *uris);
 void
 brasero_project_manager_copy (BraseroProjectManager *manager,
-			      const gchar *device);
+			      const gchar *device,
+			      const gchar *cover);
 void
 brasero_project_manager_iso (BraseroProjectManager *manager,
 			     const gchar *uri);
+void
+brasero_project_manager_burn_project (BraseroProjectManager *manager,
+				      const gchar *uri);
 
 BraseroProjectType
 brasero_project_manager_open_playlist (BraseroProjectManager *manager,
@@ -100,12 +103,13 @@ void
 brasero_project_manager_empty (BraseroProjectManager *manager);
 
 /**
- * returns TRUE on error to try to stop app closing
+ * returns the path of the project that was saved. NULL otherwise.
  */
 
 gboolean
 brasero_project_manager_save_session (BraseroProjectManager *manager,
 				      const gchar *path,
+				      gchar **saved_uri,
 				      gboolean cancellable);
 gboolean
 brasero_project_manager_load_session (BraseroProjectManager *manager,
