@@ -30,9 +30,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
 #include "brasero-disc.h"
 #include "brasero-uri-container.h"
@@ -101,6 +99,7 @@ brasero_project_load_session (BraseroProject *project, const gchar *uri);
 gboolean
 brasero_project_save_session (BraseroProject *project,
 			      const gchar *uri,
+			      gchar **saved_uri,
 			      gboolean show_cancel);
 
 void
