@@ -35,7 +35,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 #define BRASERO_TYPE_SEARCH         (brasero_search_get_type ())
