@@ -35,27 +35,16 @@
 #include <stdio.h>
 
 #include <glib.h>
-#include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
+#include <glib/gi18n-lib.h>
 
 #include <gtk/gtk.h>
 
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkmessagedialog.h>
-
 #include "brasero-sum-dialog.h"
 #include "brasero-tool-dialog.h"
-#include "burn-drive.h"
-#include "burn-medium.h"
-#include "burn-volume-obj.h"
+#include "brasero-drive.h"
+#include "brasero-medium.h"
+#include "brasero-volume.h"
 #include "brasero-xfer.h"
 #include "burn-basics.h"
 #include "burn-debug.h"
@@ -92,7 +81,6 @@ brasero_sum_dialog_stop (BraseroSumDialog *self)
 
 static gboolean
 brasero_sum_dialog_message (BraseroSumDialog *self,
-			    const gchar *title,
 			    const gchar *primary_message,
 			    const gchar *secondary_message,
 			    GtkMessageType type)
@@ -113,11 +101,10 @@ brasero_sum_dialog_message (BraseroSumDialog *self,
 					  GTK_DIALOG_DESTROY_WITH_PARENT,
 					  type,
 					  GTK_BUTTONS_NONE,
-					  primary_message);
-
-	gtk_window_set_title (GTK_WINDOW (message), title);
+					  "%s", primary_message);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
+						  "%s.",
 						  secondary_message);
 
 	button = brasero_utils_make_button (_("Check _Again"),
@@ -151,9 +138,8 @@ brasero_sum_dialog_message_error (BraseroSumDialog *self,
 					NULL);
 
 	return brasero_sum_dialog_message (self,
-					   _("File Integrity Check Error"),
-					   _("The file integrity check cannot be performed:"),
-					   error ? error->message:_("unknown error"),
+					   _("The file integrity check could not be performed."),
+					   error ? error->message:_("An unknown error occured"),
 					   GTK_MESSAGE_ERROR);
 }
 
@@ -165,9 +151,8 @@ brasero_sum_dialog_success (BraseroSumDialog *self)
 					NULL);
 
 	return brasero_sum_dialog_message (self,
-					   _("File Integrity Check Success"),
-					   _("The file integrity was performed successfully:"),
-					   _("there seems to be no corrupted file on the disc."),
+					   _("The file integrity was performed successfully."),
+					   _("There seems to be no corrupted file on the disc"),
 					   GTK_MESSAGE_INFO);
 }
 
@@ -178,9 +163,9 @@ enum {
 
 static gboolean
 brasero_sum_dialog_corruption_warning (BraseroSumDialog *self,
-				       GSList *wrong_sums)
+				       const gchar **wrong_sums)
 {
-	GSList *iter;
+	gchar *string;
 	GtkWidget *tree;
 	GtkWidget *scroll;
 	GtkWidget *button;
@@ -190,14 +175,15 @@ brasero_sum_dialog_corruption_warning (BraseroSumDialog *self,
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
+	string = g_strdup_printf ("<b><big>%s</big></b>", _("The following files appear to be corrupted:"));
 	message = gtk_message_dialog_new_with_markup (GTK_WINDOW (self),
 						      GTK_DIALOG_MODAL |
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
 						      GTK_MESSAGE_ERROR,
 						      GTK_BUTTONS_NONE,
-						      _("<b><big>The following files appear to be corrupted:</big></b>"));
+						      "%s", string);
+	g_free (string);
 
-	gtk_window_set_title (GTK_WINDOW (message),  _("File Integrity Check Error"));
 	gtk_window_set_resizable (GTK_WINDOW (message), TRUE);
 	gtk_widget_set_size_request (GTK_WIDGET (message), 440, 300);
 
@@ -216,11 +202,11 @@ brasero_sum_dialog_corruption_warning (BraseroSumDialog *self,
 
 	/* build a list */
 	model = GTK_TREE_MODEL (gtk_list_store_new (BRASERO_SUM_DIALOG_NB_COL, G_TYPE_STRING));
-	for (iter = wrong_sums; iter; iter = iter->next) {
-		gchar *path;
+	for (; wrong_sums && (*wrong_sums); wrong_sums ++) {
+		const gchar *path;
 		GtkTreeIter tree_iter;
 
-		path = iter->data;
+		path = (*wrong_sums);
 		gtk_list_store_append (GTK_LIST_STORE (model), &tree_iter);
 		gtk_list_store_set (GTK_LIST_STORE (model), &tree_iter,
 				    BRASERO_SUM_DIALOG_PATH, path,
@@ -236,7 +222,7 @@ brasero_sum_dialog_corruption_warning (BraseroSumDialog *self,
 	gtk_tree_view_column_add_attribute (column, renderer,
 					    "text", BRASERO_SUM_DIALOG_PATH);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
-	gtk_tree_view_column_set_title (column, _("Corrupted files"));
+	gtk_tree_view_column_set_title (column, _("Corrupted Files"));
 
 	scroll = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
@@ -306,11 +292,16 @@ brasero_sum_dialog_download (BraseroSumDialog *self,
 				   g_get_tmp_dir ());
 	fd = g_mkstemp (tmppath);
 	if (fd < 0) {
+		int errnum = errno;
+
 		g_free (tmppath);
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("a temporary file couldn't be created"));
+			     "%s (%s)",
+			     _("A file could not be created at the location specified for temporary files"),
+			     g_strerror (errnum));
+
 		return BRASERO_BURN_ERR;
 	}
 	close (fd);
@@ -365,7 +356,8 @@ brasero_sum_dialog_get_file_checksum (BraseroSumDialog *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("URI is not valid"));
+			     _("\"%s\" is not a valid URI"),
+			     file_path);
 		return BRASERO_BURN_ERR;
 	}
 
@@ -396,6 +388,8 @@ brasero_sum_dialog_get_file_checksum (BraseroSumDialog *self,
 	/* now get the md5 sum from the file */
 	file = fopen (src, "r");
 	if (!file) {
+                int errsv = errno;
+
 		if (tmppath)
 			g_remove (tmppath);
 
@@ -404,7 +398,8 @@ brasero_sum_dialog_get_file_checksum (BraseroSumDialog *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     strerror (errno));
+			     "%s",
+			     g_strerror (errsv));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -421,7 +416,8 @@ brasero_sum_dialog_get_file_checksum (BraseroSumDialog *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     strerror (errno));
+			     "%s",
+			     g_strerror (errno));
 
 		fclose (file);
 		return BRASERO_BURN_ERR;
@@ -472,9 +468,8 @@ brasero_sum_dialog_check_md5_file (BraseroSumDialog *self,
     	uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (self->priv->md5_chooser));
 	if (!uri) {
 		retval = brasero_sum_dialog_message (self,
-						     _("File Integrity Check Error"),
-						     _("The file integrity check cannot be performed:"),
-						     error ? error->message:_("no md5 file was given."),
+						     _("The file integrity check could not be performed."),
+						     error ? error->message:_("No md5 file was given."),
 						     GTK_MESSAGE_ERROR);
 		return retval;
 	}
@@ -530,7 +525,10 @@ brasero_sum_dialog_set_track_checksum_type (BraseroSumDialog *self,
 
 	medium = brasero_drive_get_medium (drive);
 
-	retval = brasero_volume_mount (BRASERO_VOLUME (medium), TRUE, error);
+	retval = brasero_volume_mount (BRASERO_VOLUME (medium),
+				       GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (self))),
+				       TRUE,
+				       error);
 	if (!retval)
 		return BRASERO_CHECKSUM_NONE;
 
@@ -539,8 +537,10 @@ brasero_sum_dialog_set_track_checksum_type (BraseroSumDialog *self,
 		return BRASERO_CHECKSUM_NONE;
 
 	filename = g_build_path (G_DIR_SEPARATOR_S, root, BRASERO_MD5_FILE, NULL);
+
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		g_free (filename);
+		g_free (root);
 
 		brasero_track_set_checksum (track,
 					    BRASERO_CHECKSUM_MD5_FILE,
@@ -553,6 +553,7 @@ brasero_sum_dialog_set_track_checksum_type (BraseroSumDialog *self,
 	filename = g_build_path (G_DIR_SEPARATOR_S, root, BRASERO_SHA1_FILE, NULL);
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		g_free (filename);
+		g_free (root);
 
 		brasero_track_set_checksum (track,
 					    BRASERO_CHECKSUM_SHA1_FILE,
@@ -565,6 +566,7 @@ brasero_sum_dialog_set_track_checksum_type (BraseroSumDialog *self,
 	filename = g_build_path (G_DIR_SEPARATOR_S, root, BRASERO_SHA256_FILE, NULL);
 	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		g_free (filename);
+		g_free (root);
 
 		brasero_track_set_checksum (track,
 					    BRASERO_CHECKSUM_SHA256_FILE,
@@ -573,11 +575,12 @@ brasero_sum_dialog_set_track_checksum_type (BraseroSumDialog *self,
 		return BRASERO_CHECKSUM_SHA256_FILE;
 	}
 	g_free (filename);
+	g_free (root);
 
 	g_set_error (error,
 		     BRASERO_ERROR,
 		     BRASERO_ERROR_GENERAL,
-		     _("no checksum file could be found on the disc."));
+		     _("No checksum file could be found on the disc"));
 
 	return BRASERO_CHECKSUM_NONE;
 }
@@ -587,9 +590,9 @@ brasero_sum_dialog_check_disc_sum (BraseroSumDialog *self,
 				   BraseroDrive *drive)
 {
 	BraseroChecksumType checksum_type;
-	GSList *wrong_sums = NULL;
 	BraseroBurnResult result;
 	GError *error = NULL;
+	GValue *value = NULL;
 	BraseroTrack *track;
 	BraseroBurn *burn;
 	gboolean retval;
@@ -604,15 +607,17 @@ brasero_sum_dialog_check_disc_sum (BraseroSumDialog *self,
 								    &error);
 
 	if (checksum_type == BRASERO_CHECKSUM_NONE) {
-		brasero_sum_dialog_message_error (self, error);
+		retval = brasero_sum_dialog_message_error (self, error);
 		brasero_track_unref (track);
-		g_error_free (error);
-		return FALSE;
+
+		if (error)
+			g_error_free (error);
+
+		return retval;
 	}
 
 	/* no eject at the end (it's default) */
 	brasero_burn_session_remove_flag (self->priv->session, BRASERO_BURN_FLAG_EJECT);
-
 	brasero_burn_session_add_track (self->priv->session, track);
 
 	/* It's good practice to unref the track afterwards as we don't need it
@@ -643,12 +648,11 @@ brasero_sum_dialog_check_disc_sum (BraseroSumDialog *self,
 
 	g_error_free (error);
 
-	wrong_sums = brasero_burn_session_get_wrong_checksums (self->priv->session);
-	retval = brasero_sum_dialog_corruption_warning (self, wrong_sums);
-	g_slist_foreach (wrong_sums, (GFunc) g_free, NULL);
-	g_slist_free (wrong_sums);
+	brasero_track_tag_lookup (track,
+				  BRASERO_TRACK_MEDIUM_WRONG_CHECKSUM_TAG,
+				  &value);
 
-	return retval;
+	return brasero_sum_dialog_corruption_warning (self, g_value_get_boxed (value));
 }
 
 static gboolean
@@ -757,7 +761,8 @@ brasero_sum_dialog_init (BraseroSumDialog *obj)
 
 	/* only media with data, no blank medium */
 	brasero_tool_dialog_set_medium_type_shown (BRASERO_TOOL_DIALOG (obj),
-						   BRASERO_MEDIA_TYPE_READABLE);
+						   BRASERO_MEDIA_TYPE_AUDIO|
+						   BRASERO_MEDIA_TYPE_DATA);
 
 	medium = brasero_tool_dialog_get_medium (BRASERO_TOOL_DIALOG (obj));
 	if (medium) {
@@ -774,7 +779,7 @@ brasero_sum_dialog_new ()
 	BraseroSumDialog *obj;
 	
 	obj = BRASERO_SUM_DIALOG (g_object_new (BRASERO_TYPE_SUM_DIALOG, NULL));
-	gtk_window_set_title (GTK_WINDOW (obj), "Disc Checking");
+	gtk_window_set_title (GTK_WINDOW (obj), _("Disc Checking"));
 	
 	return GTK_WIDGET (obj);
 }
