@@ -31,17 +31,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktooltips.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkaction.h>
-#include <gtk/gtktoggleaction.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtkstatusicon.h>
+#include <gtk/gtk.h>
 
 #include "burn-basics.h"
 #include "brasero-utils.h"
@@ -68,13 +58,12 @@ brasero_tray_icon_show_cb (GtkAction *action, BraseroTrayIcon *tray);
 
 struct BraseroTrayIconPrivate {
 	BraseroBurnAction action;
+	gchar *action_string;
+
 	GtkUIManager *manager;
 
-	int first_burning_percent;
 	int rounded_percent;
 	int percent;
-
-	int show_disc:1;
 };
 
 typedef enum {
@@ -89,12 +78,12 @@ static GObjectClass *parent_class = NULL;
 
 static GtkActionEntry entries[] = {
 	{"ContextualMenu", NULL, N_("Menu")},
-	{"Cancel", GTK_STOCK_CANCEL, N_("Cancel"), NULL, N_("Cancel ongoing burning"),
+	{"Cancel", GTK_STOCK_CANCEL, NULL, NULL, N_("Cancel ongoing burning"),
 	 G_CALLBACK (brasero_tray_icon_cancel_cb)},
 };
 
 static GtkToggleActionEntry toggle_entries[] = {
-	{"Show", NULL, N_("Show dialog"), NULL, N_("Show dialog"),
+	{"Show", NULL, N_("Show _Dialog"), NULL, N_("Show dialog"),
 	 G_CALLBACK (brasero_tray_icon_show_cb), TRUE,},
 };
 
@@ -219,8 +208,6 @@ brasero_tray_icon_init (BraseroTrayIcon *obj)
 			  NULL);
 
 	gtk_status_icon_set_from_icon_name (GTK_STATUS_ICON (obj), "brasero-disc-00");
-	gtk_status_icon_set_tooltip (GTK_STATUS_ICON (obj), _("waiting"));
-	obj->priv->first_burning_percent = -1;
 }
 
 static void
@@ -230,6 +217,11 @@ brasero_tray_icon_finalize (GObject *object)
 
 	cobj = BRASERO_TRAYICON (object);
 
+	if (cobj->priv->action_string) {
+		g_free (cobj->priv->action_string);
+		cobj->priv->action_string = NULL;
+	}
+
 	g_free (cobj->priv);
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -251,7 +243,10 @@ brasero_tray_icon_set_tooltip (BraseroTrayIcon *tray,
 	gchar *text;
 	const gchar *action_string;
 
-	action_string = brasero_burn_action_to_string (tray->priv->action);
+	if (!tray->priv->action_string)
+		action_string = brasero_burn_action_to_string (tray->priv->action);
+	else
+		action_string = tray->priv->action_string;
 
 	if (remaining > 0) {
 		gchar *remaining_string;
@@ -276,13 +271,18 @@ brasero_tray_icon_set_tooltip (BraseroTrayIcon *tray,
 
 void
 brasero_tray_icon_set_action (BraseroTrayIcon *tray,
-			      BraseroBurnAction action)
+			      BraseroBurnAction action,
+			      const gchar *string)
 {
-	if (action == BRASERO_BURN_ACTION_DRIVE_COPY
-	||  action == BRASERO_BURN_ACTION_RECORDING)
-		tray->priv->show_disc = TRUE;
-
 	tray->priv->action = action;
+	if (tray->priv->action_string)
+		g_free (tray->priv->action_string);
+
+	if (string)
+		tray->priv->action_string = g_strdup (string);
+	else
+		tray->priv->action_string = NULL;
+
 	brasero_tray_icon_set_tooltip (tray, -1);
 }
 
@@ -301,19 +301,6 @@ brasero_tray_icon_set_progress (BraseroTrayIcon *tray,
 	/* set the tooltip */
 	brasero_tray_icon_set_tooltip (tray, remaining);
 
-	if (!tray->priv->show_disc)
-		return;
-
-	if (tray->priv->first_burning_percent == -1)
-		tray->priv->first_burning_percent = percent;
-
-	if (tray->priv->first_burning_percent != 0) {
-		percent -= tray->priv->first_burning_percent;
-		percent = (100 - tray->priv->first_burning_percent) != 0 ?
-			   percent * 100 / (100 - tray->priv->first_burning_percent) :
-			   0;
-	}
-
 	/* change image if need be */
 	remains = percent % 5;
 	if (remains > 3)
