@@ -27,9 +27,7 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreednd.h>
-#include <gtk/gtkicontheme.h>
+#include <gtk/gtk.h>
 
 #include "burn-basics.h"
 #include "brasero-utils.h"
@@ -137,9 +135,7 @@ brasero_video_tree_model_get_value (GtkTreeModel *model,
 	case BRASERO_VIDEO_TREE_MODEL_NAME:
 		g_value_init (value, G_TYPE_STRING);
 
-		if (file->name)
-			g_value_set_string (value, file->name);
-		else if (file->info && file->info->title)
+		if (file->info && file->info->title)
 			g_value_set_string (value, file->info->title);
 		else {
 			gchar *name;
@@ -169,14 +165,14 @@ brasero_video_tree_model_get_value (GtkTreeModel *model,
 		else if (file->is_loading) {
 			pixbuf = gtk_icon_theme_load_icon (priv->theme,
 							   "image-loading",
-							   96,
+							   48,
 							   0,
 							   NULL);
 		}
 		else {
 			pixbuf = gtk_icon_theme_load_icon (priv->theme,
 							   "image-missing",
-							   96,
+							   48,
 							   0,
 							   NULL);
 		}
@@ -458,6 +454,7 @@ brasero_video_tree_model_drag_data_received (GtkTreeDragDest *drag_dest,
 			/* Add the URIs to the project */
 			brasero_video_project_add_uri (BRASERO_VIDEO_PROJECT (self),
 						       uris [i],
+						       NULL,
 						       sibling,
 						       -1,
 						       -1);
