@@ -37,11 +37,10 @@
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "burn-caps.h"
-#include "burn-hal-watch.h"
 #include "burn-plugin-manager.h"
-#include "burn-medium-monitor.h"
+#include "brasero-medium-monitor.h"
 #include "burn-plugin-private.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 
 static BraseroPluginManager *plugin_manager = NULL;
 static BraseroMediumMonitor *medium_manager = NULL;
@@ -129,5 +128,5 @@ brasero_burn_library_shutdown (void)
 	}
 
 	/* close HAL connection */
-	brasero_hal_watch_destroy ();
+//	brasero_hal_watch_destroy ();
 }
