@@ -7,7 +7,8 @@
  ****************************************************************************/
 
 /*
- * Brasero is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -312,7 +313,7 @@ stat_end:
 	}
 
 	if (size)
-		*size = BRASERO_SIZE_TO_SECTORS (buffer.st_size, 2352);
+		*size = BRASERO_BYTES_TO_SECTORS (buffer.st_size, 2352);
 
 	return TRUE;
 }
@@ -399,7 +400,7 @@ stat_end:
 	}
 
 	if (size)
-		*size = BRASERO_SIZE_TO_SECTORS (buffer.st_size, 2352) - start;
+		*size = BRASERO_BYTES_TO_SECTORS (buffer.st_size, 2352) - start;
 
 	return TRUE;
 }
@@ -648,7 +649,7 @@ brasero_image_format_get_cue_size (gchar *path,
 	if (size)
 		*size = cue_size;
 	if (blocks)
-		*blocks = BRASERO_SIZE_TO_SECTORS (cue_size, 2352);
+		*blocks = BRASERO_BYTES_TO_SECTORS (cue_size, 2352);
 
 	return TRUE;
 }
