@@ -7,7 +7,8 @@
  ****************************************************************************/
 
 /*
- * Brasero is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -46,6 +47,13 @@ typedef enum {
 BraseroImageFormat
 brasero_image_format_identify_cuesheet (const gchar *path);
 
+gchar *
+brasero_image_format_get_default_path (BraseroImageFormat format);
+
+gchar *
+brasero_image_format_fix_path_extension (BraseroImageFormat format,
+					 gboolean check_existence,
+					 gchar *path);
 gchar *
 brasero_image_format_get_complement (BraseroImageFormat format,
 				     const gchar *path);
