@@ -43,9 +43,9 @@
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "burn-track.h"
-#include "burn-medium.h"
-#include "burn-drive.h"
-#include "burn-medium-monitor.h"
+#include "brasero-medium.h"
+#include "brasero-drive.h"
+#include "brasero-medium-monitor.h"
 
 G_DEFINE_TYPE (BraseroBurnSession, brasero_burn_session, G_TYPE_OBJECT);
 #define BRASERO_BURN_SESSION_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_BURN_SESSION, BraseroBurnSessionPrivate))
@@ -53,8 +53,6 @@ G_DEFINE_TYPE (BraseroBurnSession, brasero_burn_session, G_TYPE_OBJECT);
 struct _BraseroSessionSetting {
 	BraseroDrive *burner;
 
-	guint num_copies;
-
 	/**
 	 * Used when outputting an image instead of burning
 	 */
@@ -329,14 +327,19 @@ brasero_burn_session_set_input_type (BraseroBurnSession *self,
 				     BraseroTrackType *type)
 {
 	BraseroBurnSessionPrivate *priv;
+	BraseroTrackType input = { 0, };
 
 	g_return_if_fail (BRASERO_IS_BURN_SESSION (self));
 	g_return_if_fail (type != NULL);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
+	brasero_burn_session_get_input_type (self, &input);
 	memcpy (&priv->input, type, sizeof (BraseroTrackType));
 
+	if (brasero_track_type_equal (&input, type))
+		return;
+
 	if (!priv->tracks)
 		g_signal_emit (self,
 			       brasero_burn_session_signals [INPUT_CHANGED_SIGNAL],
@@ -488,37 +491,6 @@ brasero_burn_session_get_rate (BraseroBurnSession *self)
 		return MIN (max_rate, priv->settings->rate);
 }
 
-void
-brasero_burn_session_set_num_copies (BraseroBurnSession *self,
-				     guint copies)
-{
-	BraseroBurnSessionPrivate *priv;
-
-	g_return_if_fail (BRASERO_IS_BURN_SESSION (self));
-
-	priv = BRASERO_BURN_SESSION_PRIVATE (self);
-
-	if (!BRASERO_BURN_SESSION_WRITE_TO_DISC (priv))
-		return;
-
-	priv->settings->num_copies = copies;
-}
-
-guint
-brasero_burn_session_get_num_copies (BraseroBurnSession *self)
-{
-	BraseroBurnSessionPrivate *priv;
-
-	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), 0);
-
-	priv = BRASERO_BURN_SESSION_PRIVATE (self);
-
-	if (!BRASERO_BURN_SESSION_WRITE_TO_DISC (priv))
-		return 1;
-
-	return priv->settings->num_copies;
-}
-
 /**
  * This function returns a path only if we should output to a file image
  * and not burn.
@@ -563,8 +535,8 @@ brasero_burn_session_get_output (BraseroBurnSession *self,
 
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
-					     BRASERO_BURN_ERROR_GENERAL,
-					     _("no output specified"));
+					     BRASERO_BURN_ERROR_OUTPUT_NONE,
+					     _("No path was specified for the image output"));
 
 				g_free (toc);
 				return BRASERO_BURN_ERR;
@@ -579,8 +551,8 @@ brasero_burn_session_get_output (BraseroBurnSession *self,
 
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
-				     _("no output specified"));
+				     BRASERO_BURN_ERROR_OUTPUT_NONE,
+				     _("No path was specified for the image output"));
 			return BRASERO_BURN_ERR;
 		}
 	}
@@ -670,7 +642,7 @@ brasero_burn_session_set_image_output_full (BraseroBurnSession *self,
 		GSList *list;
 
 		monitor = brasero_medium_monitor_get_default ();
-		list = brasero_medium_monitor_get_media (monitor, BRASERO_MEDIA_TYPE_FILE);
+		list = brasero_medium_monitor_get_media (monitor,BRASERO_MEDIA_TYPE_FILE);
 		drive = brasero_medium_get_drive (list->data);
 		brasero_burn_session_set_burner (self, drive);
 		g_object_unref (monitor);
@@ -747,12 +719,19 @@ brasero_burn_session_get_tmp_dir (BraseroBurnSession *self,
 	if (*path == NULL) {
                 int errsv = errno;
 
+		BRASERO_BURN_LOG ("Impossible to create tmp directory");
 		g_free (tmp);
-		g_set_error (error,
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_GENERAL,
-			     _("a temporary directory could not be created (%s)"),
-			     g_strerror (errsv));
+		if (errsv != EACCES)
+			g_set_error (error, 
+				     BRASERO_BURN_ERROR,
+				     BRASERO_BURN_ERROR_GENERAL,
+				     "%s",
+				     g_strerror (errsv));
+		else
+			g_set_error (error,
+				     BRASERO_BURN_ERROR,
+				     BRASERO_BURN_ERROR_PERMISSION,
+				     _("You do not have the required permission to write at this location"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -798,11 +777,19 @@ brasero_burn_session_get_tmp_file (BraseroBurnSession *self,
                 int errsv = errno;
 
 		g_free (tmp);
-		g_set_error (error, 
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_GENERAL,
-			     _("a temporary file can't be created: %s"),
-			     g_strerror (errsv));
+		BRASERO_BURN_LOG ("Impossible to create tmp file");
+		if (errsv != EACCES)
+			g_set_error (error, 
+				     BRASERO_BURN_ERROR,
+				     BRASERO_BURN_ERROR_GENERAL,
+				     "%s",
+				     g_strerror (errsv));
+		else
+			g_set_error (error, 
+				     BRASERO_BURN_ERROR,
+				     BRASERO_BURN_ERROR_PERMISSION,
+				     _("You do not have the required permission to write at this location"));
+
 		return BRASERO_BURN_ERR;
 	}
 
@@ -1415,9 +1402,16 @@ brasero_burn_session_start (BraseroBurnSession *self)
 
 	if (!priv->session_path) {
 		int fd;
+		const gchar *tmpdir;
 
+		/* takes care of the output file */
+		tmpdir = priv->settings->tmpdir ?
+			 priv->settings->tmpdir :
+			 g_get_tmp_dir ();
+
+		/* This must obey the path of the temporary directory */
 		priv->session_path = g_build_path (G_DIR_SEPARATOR_S,
-						   g_get_tmp_dir (),
+						   tmpdir,
 						   BRASERO_BURN_TMP_FILE_NAME,
 						   NULL);
 
@@ -1446,7 +1440,6 @@ brasero_burn_session_start (BraseroBurnSession *self)
 		medium = brasero_drive_get_medium (priv->settings->burner);
 		BRASERO_BURN_LOG_DISC_TYPE (brasero_medium_get_status (medium), "media type\t=");
 		BRASERO_BURN_LOG ("speed\t= %i", priv->settings->rate);
-		BRASERO_BURN_LOG ("number of copies\t= %i", priv->settings->num_copies);
 	}
 	else {
 		type.type = BRASERO_TRACK_TYPE_IMAGE;
@@ -1641,7 +1634,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	brasero_burn_session_signals [OUTPUT_CHANGED_SIGNAL] =
 	    g_signal_new ("output_changed",
 			  BRASERO_TYPE_BURN_SESSION,
-			  G_SIGNAL_RUN_FIRST|G_SIGNAL_ACTION|G_SIGNAL_NO_RECURSE,
+			  G_SIGNAL_RUN_FIRST,
 			  G_STRUCT_OFFSET (BraseroBurnSessionClass, output_changed),
 			  NULL,
 			  NULL,
@@ -1652,7 +1645,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	brasero_burn_session_signals [INPUT_CHANGED_SIGNAL] =
 	    g_signal_new ("input_changed",
 			  BRASERO_TYPE_BURN_SESSION,
-			  G_SIGNAL_RUN_FIRST|G_SIGNAL_ACTION|G_SIGNAL_NO_RECURSE,
+			  G_SIGNAL_RUN_FIRST,
 			  G_STRUCT_OFFSET (BraseroBurnSessionClass, input_changed),
 			  NULL,
 			  NULL,
