@@ -7,7 +7,8 @@
  ****************************************************************************/
 
 /*
- * Brasero is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -37,9 +38,9 @@
 
 #include "burn-track.h"
 #include "burn-debug.h"
-#include "burn-medium.h"
+#include "brasero-medium.h"
 #include "burn-image-format.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 #include "burn-mkisofs-base.h"
 
 struct _BraseroTrack {
