@@ -39,19 +39,29 @@
 #include <glib/gstdio.h>
 #include <gmodule.h>
 
+#include <gconf/gconf-client.h>
+
 #include "burn-cdrdao-common.h"
 #include "burn-cdrdao.h"
 #include "burn-basics.h"
 #include "burn-plugin.h"
 #include "burn-job.h"
 #include "burn-process.h"
-#include "burn-drive.h"
-#include "burn-medium.h"
+#include "brasero-drive.h"
+#include "brasero-medium.h"
 
 BRASERO_PLUGIN_BOILERPLATE (BraseroCdrdao, brasero_cdrdao, BRASERO_TYPE_PROCESS, BraseroProcess);
 
+struct _BraseroCdrdaoPrivate {
+  	guint use_raw:1;
+};
+typedef struct _BraseroCdrdaoPrivate BraseroCdrdaoPrivate;
+#define BRASERO_CDRDAO_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_CDRDAO, BraseroCdrdaoPrivate)) 
+
 static GObjectClass *parent_class = NULL;
 
+#define GCONF_KEY_RAW_FLAG "/apps/brasero/config/raw_flag" 
+
 static gboolean
 brasero_cdrdao_read_stderr_image (BraseroCdrdao *cdrdao, const gchar *line)
 {
@@ -184,8 +194,9 @@ brasero_cdrdao_read_stderr_record (BraseroCdrdao *cdrdao, const gchar *line)
 
 		brasero_job_error (BRASERO_JOB (cdrdao),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("the cue file (%s) seems to be invalid"),
+						BRASERO_BURN_ERROR_FILE_NOT_FOUND,
+						/* Translators: %s is a filename */
+						_("\"%s\" could not be found"),
 						name));
 		g_free (name);
 	}
@@ -216,20 +227,20 @@ brasero_cdrdao_read_stderr (BraseroProcess *process, const gchar *line)
 	if (strstr (line, "Cannot setup device")) {
 		brasero_job_error (BRASERO_JOB (cdrdao),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_BUSY_DRIVE,
-						_("the drive seems to be busy")));
+						BRASERO_BURN_ERROR_DRIVE_BUSY,
+						_("The drive is busy")));
 	}
 	else if (strstr (line, "Illegal command")) {
 		brasero_job_error (BRASERO_JOB (cdrdao),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_GENERAL,
-						_("your version of cdrdao doesn't seem to be supported by libbrasero")));
+						_("Your version of cdrdao does not seem to be supported by libbrasero")));
 	}
 	else if (strstr (line, "Operation not permitted. Cannot send SCSI")) {
 		brasero_job_error (BRASERO_JOB (cdrdao),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_SCSI_IOCTL,
-						_("You don't seem to have the required permission to use this drive")));
+						BRASERO_BURN_ERROR_PERMISSION,
+						_("You do not have the required permissions to use this drive")));
 	}
 
 	return BRASERO_BURN_OK;
@@ -261,13 +272,16 @@ brasero_cdrdao_set_argv_common_rec (BraseroCdrdao *cdrdao,
 	gchar *speed_str;
 	guint speed;
 
+	brasero_job_get_flags (BRASERO_JOB (cdrdao), &flags);
+	if (flags & BRASERO_BURN_FLAG_DUMMY)
+		g_ptr_array_add (argv, g_strdup ("--simulate"));
+
 	g_ptr_array_add (argv, g_strdup ("--speed"));
 
 	brasero_job_get_speed (BRASERO_JOB (cdrdao), &speed);
 	speed_str = g_strdup_printf ("%d", speed);
 	g_ptr_array_add (argv, speed_str);
 
-	brasero_job_get_flags (BRASERO_JOB (cdrdao), &flags);
 	if (flags & BRASERO_BURN_FLAG_OVERBURN)
 		g_ptr_array_add (argv, g_strdup ("--overburn"));
 	if (flags & BRASERO_BURN_FLAG_MULTI)
@@ -281,8 +295,6 @@ brasero_cdrdao_set_argv_common (BraseroCdrdao *cdrdao,
 	BraseroBurnFlag flags;
 
 	brasero_job_get_flags (BRASERO_JOB (cdrdao), &flags);
-	if (flags & BRASERO_BURN_FLAG_DUMMY)
-		g_ptr_array_add (argv, g_strdup ("--simulate"));
 
 	/* cdrdao manual says it is a similar option to gracetime */
 	if (flags & BRASERO_BURN_FLAG_NOGRACE)
@@ -297,6 +309,9 @@ brasero_cdrdao_set_argv_record (BraseroCdrdao *cdrdao,
 				GPtrArray *argv)
 {
 	BraseroTrackType type;
+	BraseroCdrdaoPrivate *priv;
+
+	priv = BRASERO_CDRDAO_PRIVATE (cdrdao); 
 
 	g_ptr_array_add (argv, g_strdup ("cdrdao"));
 
@@ -315,6 +330,9 @@ brasero_cdrdao_set_argv_record (BraseroCdrdao *cdrdao,
 		if (flags & BRASERO_BURN_FLAG_NO_TMP_FILES)
 			g_ptr_array_add (argv, g_strdup ("--on-the-fly"));
 
+		if (priv->use_raw)
+		  	g_ptr_array_add (argv, g_strdup ("--driver generic-mmc-raw")); 
+
 		g_ptr_array_add (argv, g_strdup ("--source-device"));
 
 		brasero_job_get_current_track (BRASERO_JOB (cdrdao), &track);
@@ -375,11 +393,12 @@ brasero_cdrdao_set_argv_blank (BraseroCdrdao *cdrdao,
 	brasero_cdrdao_set_argv_device (cdrdao, argv);
 	brasero_cdrdao_set_argv_common (cdrdao, argv);
 
+	g_ptr_array_add (argv, g_strdup ("--blank-mode"));
 	brasero_job_get_flags (BRASERO_JOB (cdrdao), &flags);
-	if (!(flags & BRASERO_BURN_FLAG_FAST_BLANK)) {
-		g_ptr_array_add (argv, g_strdup ("--blank-mode"));
+	if (!(flags & BRASERO_BURN_FLAG_FAST_BLANK))
 		g_ptr_array_add (argv, g_strdup ("full"));
-	}
+	else
+		g_ptr_array_add (argv, g_strdup ("minimal"));
 
 	brasero_job_set_current_action (BRASERO_JOB (cdrdao),
 					BRASERO_BURN_ACTION_BLANKING,
@@ -420,7 +439,6 @@ brasero_cdrdao_set_argv_image (BraseroCdrdao *cdrdao,
 	/* This is done so that if a cue file is required we first generate
 	 * a temporary toc file that will be later converted to a cue file.
 	 * The datafile is written where it should be from the start. */
-
 	brasero_job_get_output_type (BRASERO_JOB (cdrdao), &output);
 	if (output.subtype.img_format == BRASERO_IMAGE_FORMAT_CDRDAO) {
 		result = brasero_job_get_image_output (BRASERO_JOB (cdrdao),
@@ -525,6 +543,8 @@ brasero_cdrdao_class_init (BraseroCdrdaoClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	BraseroProcessClass *process_class = BRASERO_PROCESS_CLASS (klass);
 
+	g_type_class_add_private (klass, sizeof (BraseroCdrdaoPrivate));
+
 	parent_class = g_type_class_peek_parent(klass);
 	object_class->finalize = brasero_cdrdao_finalize;
 
@@ -535,7 +555,20 @@ brasero_cdrdao_class_init (BraseroCdrdaoClass *klass)
 
 static void
 brasero_cdrdao_init (BraseroCdrdao *obj)
-{  }
+{  
+	GConfClient *client;
+ 	BraseroCdrdaoPrivate *priv;
+ 	
+	/* load our "configuration" */
+ 	priv = BRASERO_CDRDAO_PRIVATE (obj);
+ 	
+ 	client = gconf_client_get_default ();
+ 	priv->use_raw = gconf_client_get_bool (client,
+					       GCONF_KEY_RAW_FLAG,
+					       NULL);
+
+ 	g_object_unref (client); 
+}
 
 static void
 brasero_cdrdao_finalize (GObject *object)
@@ -548,7 +581,8 @@ brasero_cdrdao_export_caps (BraseroPlugin *plugin, gchar **error)
 {
 	GSList *input;
 	GSList *output;
-	gchar *prog_name;
+	BraseroBurnResult result;
+	BraseroPluginConfOption *use_raw; 
 	const BraseroMedia media_w = BRASERO_MEDIUM_CD|
 				     BRASERO_MEDIUM_WRITABLE|
 				     BRASERO_MEDIUM_REWRITABLE|
@@ -562,19 +596,15 @@ brasero_cdrdao_export_caps (BraseroPlugin *plugin, gchar **error)
 				      BRASERO_MEDIUM_BLANK;
 
 	brasero_plugin_define (plugin,
-			       "cdrdao",
-			       _("use cdrdao to image and burn CDs"),
+			       "Cdrdao",
+			       _("Use cdrdao to copy and burn CDs"),
 			       "Philippe Rouquier",
 			       20);
 
-	/* First see if this plugin can be used, i.e. if readcd is in
-	 * the path */
-	prog_name = g_find_program_in_path ("cdrdao");
-	if (!prog_name) {
-		*error = g_strdup (_("cdrdao could not be found in the path"));
-		return BRASERO_BURN_ERR;
-	}
-	g_free (prog_name);
+	/* First see if this plugin can be used */
+	result = brasero_process_check_path ("cdrdao", error);
+	if (result != BRASERO_BURN_OK)
+		return result;
 
 	/* that's for cdrdao images: CDs only as input */
 	input = brasero_caps_disc_new (BRASERO_MEDIUM_CD|
@@ -632,6 +662,12 @@ brasero_cdrdao_export_caps (BraseroPlugin *plugin, gchar **error)
 					BRASERO_BURN_FLAG_FAST_BLANK,
 					BRASERO_BURN_FLAG_NONE);
 
+	use_raw = brasero_plugin_conf_option_new (GCONF_KEY_RAW_FLAG,
+						  _("Enable \"--driver generic-mmc-raw\" flag (see cdrdao manual)"),
+						  BRASERO_PLUGIN_OPTION_BOOL);
+
+	brasero_plugin_add_conf_option (plugin, use_raw);
+
 	brasero_plugin_register_group (plugin, _(CDRDAO_DESCRIPTION));
 	return BRASERO_BURN_OK;
 }
