@@ -48,8 +48,8 @@
 #include "burn-job.h"
 #include "burn-checksum-files.h"
 #include "burn-volume.h"
-#include "burn-drive.h"
-#include "burn-volume-obj.h"
+#include "brasero-drive.h"
+#include "brasero-volume.h"
 #include "burn-volume-read.h"
 
 BRASERO_PLUGIN_BOILERPLATE (BraseroChecksumFiles, brasero_checksum_files, BRASERO_TYPE_JOB, BraseroJob);
@@ -66,6 +66,8 @@ struct _BraseroChecksumFilesPrivate {
 
 	/* this is for the thread and the end of it */
 	GThread *thread;
+	GMutex *mutex;
+	GCond *cond;
 	gint end_id;
 
 	guint cancel;
@@ -96,6 +98,7 @@ brasero_checksum_files_get_file_checksum (BraseroChecksumFiles *self,
 
 	file = fopen (path, "r");
 	if (!file) {
+                int errsv;
 		gchar *name = NULL;
 
 		/* If the file doesn't exist carry on with next */
@@ -104,12 +107,13 @@ brasero_checksum_files_get_file_checksum (BraseroChecksumFiles *self,
 
 		name = g_path_get_basename (path);
 
+                errsv = errno;
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the file %s couldn't be read (%s)"),
+			     _("File \"%s\" could not be opened (%s)"),
 			     name,
-			     strerror (errno));
+			     g_strerror (errsv));
 		g_free (name);
 
 		return BRASERO_BURN_ERR;
@@ -121,8 +125,11 @@ brasero_checksum_files_get_file_checksum (BraseroChecksumFiles *self,
 	g_checksum_update (checksum, buffer, read_bytes);
 
 	while (read_bytes == BLOCK_SIZE) {
-		if (priv->cancel)
+		if (priv->cancel) {
+			fclose (file);
+			g_checksum_free (checksum);
 			return BRASERO_BURN_CANCEL;
+		}
 
 		read_bytes = fread (buffer, 1, BLOCK_SIZE, file);
 		g_checksum_update (checksum, buffer, read_bytes);
@@ -165,11 +172,12 @@ brasero_checksum_files_add_file_checksum (BraseroChecksumFiles *self,
 	g_free (checksum_string);
 
 	if (written != 1) {
+                int errsv = errno;
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the md5 file couldn't be written to (%s)"),
-			     strerror (errno));
+			     _("Data could not be written (%s)"),
+			     g_strerror (errsv));
 			
 		return BRASERO_BURN_ERR;
 	}
@@ -187,11 +195,12 @@ brasero_checksum_files_add_file_checksum (BraseroChecksumFiles *self,
 			  priv->file);
 
 	if (written != 1) {
+                int errsv = errno;
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the md5 file couldn't be written to (%s)"),
-			     strerror (errno));
+			     _("Data could not be written (%s)"),
+			     g_strerror (errsv));
 
 		return BRASERO_BURN_ERR;
 	}
@@ -257,6 +266,13 @@ brasero_checksum_files_explore_directory (BraseroChecksumFiles *self,
 			continue;
 		}
 
+		/* Only checksum regular files and avoid fifos, ... */
+		if (!g_file_test (path, G_FILE_TEST_IS_REGULAR)) {
+			g_free (path);
+			g_free (graft_path);
+			continue;
+		}
+
 		result = brasero_checksum_files_add_file_checksum (self,
 								   path,
 								   checksum_type,
@@ -334,7 +350,8 @@ brasero_checksum_file_process_former_line (BraseroChecksumFiles *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     strerror (errno));
+			     "%s",
+			     g_strerror (errno));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -342,7 +359,8 @@ brasero_checksum_file_process_former_line (BraseroChecksumFiles *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     strerror (errno));
+			     "%s",
+			     g_strerror (errno));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -380,7 +398,7 @@ brasero_checksum_files_merge_with_former_session (BraseroChecksumFiles *self,
 
 	/* try every file and make sure they are of the same type */
 	brasero_job_get_device (BRASERO_JOB (self), &device);
-	dev_handle = brasero_device_handle_open (device, NULL);
+	dev_handle = brasero_device_handle_open (device, FALSE, NULL);
 	g_free (device);
 
 	vol = brasero_volume_source_open_device_handle (dev_handle, error);
@@ -535,16 +553,19 @@ brasero_checksum_files_create_checksum (BraseroChecksumFiles *self,
 		break;
 	}
 
-	if (result != BRASERO_BURN_OK)
+	if (result != BRASERO_BURN_OK || !priv->sums_path)
 		return result;
 
 	priv->file = fopen (priv->sums_path, "w");
 	if (!priv->file) {
+                int errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("md5 file couldn't be opened (%s)"),
-			     strerror (errno));
+			     _("File \"%s\" could not be opened (%s)"),
+			     priv->sums_path,
+			     g_strerror (errsv));
 
 		return BRASERO_BURN_ERR;
 	}
@@ -586,7 +607,6 @@ brasero_checksum_files_create_checksum (BraseroChecksumFiles *self,
 		BraseroGraftPt *graft;
 		gchar *graft_path;
 		gchar *path;
-		gchar *uri;
 
 		if (priv->cancel) {
 			result = BRASERO_BURN_CANCEL;
@@ -598,8 +618,17 @@ brasero_checksum_files_create_checksum (BraseroChecksumFiles *self,
 			continue;
 
 		/* get the current and future paths */
-		uri = graft->uri;
-		path = g_filename_from_uri (uri, NULL, NULL);
+		/* FIXME: graft->uri can be path or URIs ... This should be
+		 * fixed for graft points. */
+		if (!graft->uri)
+			path = NULL;
+		else if (graft->uri [0] == '/')
+			path = g_strdup (graft->uri);
+		else if (g_str_has_prefix (graft->uri, "file://"))
+			path = g_filename_from_uri (graft->uri, NULL, NULL);
+		else
+			path = NULL;
+
 		graft_path = graft->path;
 
 		if (g_file_test (path, G_FILE_TEST_IS_DIR))
@@ -656,7 +685,8 @@ brasero_checksum_files_get_line_num (BraseroChecksumFiles *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     strerror (errno));
+			     "%s",
+			     g_strerror (errno));
 		return -1;
 	}
 
@@ -678,17 +708,16 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 	const gchar *name;
 	gint checksum_len;
 	BraseroTrack *track;
+	GValue *value = NULL;
 	BraseroMedium *medium;
-	gboolean has_wrongsums;
 	GChecksumType gchecksum_type;
-	BraseroChecksumFilesPrivate *priv;
+	GArray *wrong_checksums = NULL;
 	gchar filename [MAXPATHLEN + 1];
+	BraseroChecksumFilesPrivate *priv;
 	BraseroBurnResult result = BRASERO_BURN_OK;
 
 	priv = BRASERO_CHECKSUM_FILES_PRIVATE (self);
 
-	has_wrongsums = FALSE;
-
 	brasero_job_get_current_track (BRASERO_JOB (self), &track);
 	medium = brasero_track_get_medium_source (track);
 	root = brasero_volume_get_mount_point (BRASERO_VOLUME (medium), FALSE);
@@ -709,17 +738,24 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     strerror (errno));
+			     "%s",
+			     g_strerror (errno));
 		return BRASERO_BURN_ERR;
 	}
 
 	/* we need to get the number of files at this time and rewind */
 	file_nb = brasero_checksum_files_get_line_num (self, file, error);
-	if (file_nb < 1) {
+	if (file_nb == 0) {
+		fclose (file);
+		return BRASERO_BURN_OK;
+	}
+
+	if (file_nb < 0) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     strerror (errno));
+			     "%s",
+			     g_strerror (errno));
 		fclose (file);
 		return BRASERO_BURN_ERR;
 	}
@@ -763,7 +799,8 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     strerror (errno));
+					     "%s",
+					     g_strerror (errno));
 			break;
 		}
 		checksum_file [checksum_len] = '\0';
@@ -785,7 +822,8 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     strerror (errno));
+					     "%s",
+					     g_strerror (errno));
 				goto end;
 			}
 
@@ -809,7 +847,8 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     strerror (errno));
+					     "%s",
+					     g_strerror (errno));
 				goto end;
 			}
 
@@ -827,6 +866,11 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 
 		filename [i] = 0;
 		checksum_real = NULL;
+
+		/* we certainly don't want to checksum anything but regular file */
+		if (!g_file_test (filename, G_FILE_TEST_IS_REGULAR))
+			continue;
+
 		result = brasero_checksum_files_get_file_checksum (self,
 								   gchecksum_type,
 								   filename,
@@ -847,8 +891,15 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 				 filename, checksum_file, checksum_real);
 
 		if (strcmp (checksum_file, checksum_real)) {
-			has_wrongsums = TRUE;
-			brasero_job_add_wrong_checksum (BRASERO_JOB (self), filename);
+			gchar *string;
+			if (!wrong_checksums)
+				wrong_checksums = g_array_new (TRUE,
+							       TRUE, 
+							       sizeof (gchar *));
+
+			string = g_strdup (filename);
+			wrong_checksums = g_array_append_val (wrong_checksums,
+							      string);
 		}
 
 		g_free (checksum_real);
@@ -863,15 +914,25 @@ end:
 	if (result != BRASERO_BURN_OK)
 		return result;
 
-	if (has_wrongsums) {
-		g_set_error (error,
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_BAD_CHECKSUM,
-			     _("some files may be corrupted on the disc"));
-		return BRASERO_BURN_ERR;
-	}
+	if (!wrong_checksums)
+		return BRASERO_BURN_OK;
 
-	return BRASERO_BURN_OK;
+	/* add the tag */
+	value = g_new0 (GValue, 1);
+	g_value_init (value, G_TYPE_STRV);
+	g_value_take_boxed (value, wrong_checksums->data);
+	g_array_free (wrong_checksums, FALSE);
+
+	brasero_track_tag_add (track,
+			       BRASERO_TRACK_MEDIUM_WRONG_CHECKSUM_TAG,
+			       value);
+
+	g_set_error (error,
+		     BRASERO_BURN_ERROR,
+		     BRASERO_BURN_ERROR_BAD_CHECKSUM,
+		     _("Some files may be corrupted on the disc"));
+
+	return BRASERO_BURN_ERR;
 }
 
 struct _BraseroChecksumFilesThreadCtx {
@@ -987,7 +1048,7 @@ error:
 
 	error = g_error_new (BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_BAD_CHECKSUM,
-			     _("some files may be corrupted on the disc"));
+			     _("Some files may be corrupted on the disc"));
 	brasero_job_error (BRASERO_JOB (self), error);
 	return FALSE;
 }
@@ -1055,7 +1116,12 @@ brasero_checksum_files_thread (gpointer data)
 						brasero_checksum_files_destroy);
 	}
 
+	/* End thread */
+	g_mutex_lock (priv->mutex);
 	priv->thread = NULL;
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 	return NULL;
 }
@@ -1076,10 +1142,12 @@ brasero_checksum_files_start (BraseroJob *job,
 
 	/* we start a thread for the exploration of the graft points */
 	priv = BRASERO_CHECKSUM_FILES_PRIVATE (job);
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_checksum_files_thread,
 					BRASERO_CHECKSUM_FILES (job),
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
 
 	if (!priv->thread)
 		return BRASERO_BURN_ERR;
@@ -1100,7 +1168,8 @@ brasero_checksum_files_activate (BraseroJob *job,
 		return BRASERO_BURN_OK;
 
 	/* see that a file with graft "/BRASERO_CHECKSUM_FILE" doesn't already
-	 * exists (possible when doing several copies) */
+	 * exists (possible when doing several copies) or when a simulation 
+	 * already took place before. */
 	brasero_job_get_current_track (job, &track);
 	grafts = brasero_track_get_data_grafts_source (track);
 	for (; grafts; grafts = grafts->next) {
@@ -1141,12 +1210,14 @@ brasero_checksum_files_stop (BraseroJob *job,
 
 	priv = BRASERO_CHECKSUM_FILES_PRIVATE (job);
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 		priv->thread = NULL;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->end_id) {
 		g_source_remove (priv->end_id);
@@ -1168,7 +1239,13 @@ brasero_checksum_files_stop (BraseroJob *job,
 
 static void
 brasero_checksum_files_init (BraseroChecksumFiles *obj)
-{ }
+{	BraseroChecksumFilesPrivate *priv;
+
+	priv = BRASERO_CHECKSUM_FILES_PRIVATE (obj);
+
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+}
 
 static void
 brasero_checksum_files_finalize (GObject *object)
@@ -1177,12 +1254,14 @@ brasero_checksum_files_finalize (GObject *object)
 	
 	priv = BRASERO_CHECKSUM_FILES_PRIVATE (object);
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 		priv->thread = NULL;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->end_id) {
 		g_source_remove (priv->end_id);
@@ -1194,6 +1273,16 @@ brasero_checksum_files_finalize (GObject *object)
 		priv->file = NULL;
 	}
 
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -1221,8 +1310,11 @@ brasero_checksum_files_export_caps (BraseroPlugin *plugin, gchar **error)
 	BraseroPluginConfOption *checksum_type;
 
 	brasero_plugin_define (plugin,
-			       "File checksum",
-			       _("allows to check file integrities on a disc"),
+			       /* Translators: this is the name of the plugin
+				* which will be translated only when it needs
+				* displaying. */
+			       N_("File Checksum"),
+			       _("Allows to check file integrities on a disc"),
 			       "Philippe Rouquier",
 			       0);
 
@@ -1231,9 +1323,10 @@ brasero_checksum_files_export_caps (BraseroPlugin *plugin, gchar **error)
 	brasero_plugin_process_caps (plugin, input);
 	g_slist_free (input);
 
+	/* we can run on initial track or later for whatever a DATA track */
 	brasero_plugin_set_process_flags (plugin,
-					  BRASERO_PLUGIN_RUN_FIRST|
-					  BRASERO_PLUGIN_RUN_LAST);
+					  BRASERO_PLUGIN_RUN_PREPROCESSING|
+					  BRASERO_PLUGIN_RUN_BEFORE_TARGET);
 
 	/* For discs, we can only check each files on a disc against an md5sum 
 	 * file (provided we managed to mount the disc).
@@ -1242,7 +1335,7 @@ brasero_checksum_files_export_caps (BraseroPlugin *plugin, gchar **error)
 	 * equivalent instead */
 	input = brasero_caps_disc_new (BRASERO_MEDIUM_CD|
 				       BRASERO_MEDIUM_DVD|
-				       BRASERO_MEDIUM_DVD_DL|
+				       BRASERO_MEDIUM_DUAL_L|
 				       BRASERO_MEDIUM_PLUS|
 				       BRASERO_MEDIUM_RESTRICTED|
 				       BRASERO_MEDIUM_SEQUENTIAL|
