@@ -41,7 +41,7 @@
 #include <gst/gst.h>
 
 #include "burn-basics.h"
-#include "burn-medium.h"
+#include "brasero-medium.h"
 #include "burn-job.h"
 #include "burn-plugin.h"
 #include "burn-transcode.h"
@@ -314,7 +314,10 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("source can't be created"));
+			     /* Translators: %s is the name of the GstElement that 
+			      * could not be created */
+			     _("%s element could not be created"),
+			     "\"Source\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (pipeline), source);
@@ -362,7 +365,8 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("sink can't be created"));
+			     _("%s element could not be created"),
+			     "\"Sink\"");
 		goto error;
 	}
 
@@ -377,7 +381,8 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("audioconvert can't be created"));
+			     _("%s element could not be created"),
+			     "\"Audioconvert\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (pipeline), convert);
@@ -389,7 +394,8 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("audioresample can't be created"));
+				     _("%s element could not be created"),
+				     "\"Audioresample\"");
 			goto error;
 		}
 		gst_bin_add (GST_BIN (pipeline), resample);
@@ -400,7 +406,8 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("filter can't be created"));
+				     _("%s element could not be created"),
+				     "\"Filter\"");
 			goto error;
 		}
 		gst_bin_add (GST_BIN (pipeline), filter);
@@ -423,7 +430,8 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("decode can't be created"));
+			     _("%s element could not be created"),
+			     "\"Decodebin\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (pipeline), decode);
@@ -582,7 +590,8 @@ brasero_transcode_create_sibling_image (BraseroTranscode *transcode,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("a symlink could not be created (%s)"),
+			     /* Translators: the %s is the error message from errno */
+			     _("An internal error occured (%s)"),
 			     g_strerror (errsv));
 
 		goto error;
@@ -840,7 +849,8 @@ brasero_transcode_pad_real (BraseroTranscode *transcode,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("error padding (%s)"),
+				     /* Translators: %s is the string error from errno */
+				     _("Error while padding file (%s)"),
 				     g_strerror (errsv));
 			return -1;
 		}
@@ -1032,7 +1042,8 @@ brasero_transcode_pad_file (BraseroTranscode *transcode, GError **error)
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("error opening file for padding : %s"),
+			     /* Translators: %s is the string error from errno */
+			     _("Error while padding file (%s)"),
 			     g_strerror (errsv));
 		return FALSE;
 	}
@@ -1129,7 +1140,7 @@ brasero_transcode_get_duration (BraseroTranscode *transcode)
 	    brasero_job_error (BRASERO_JOB (transcode),
 			       g_error_new (BRASERO_BURN_ERROR,
 					    BRASERO_BURN_ERROR_GENERAL,
-					    _("error getting duration")));
+					    _("Error while getting duration")));
 	return duration;
 }
 
@@ -1192,18 +1203,18 @@ foreach_tag (const GstTagList *list,
 	brasero_job_get_current_track (BRASERO_JOB (transcode), &track);
 	info = brasero_track_get_audio_info (track);
 
-	if (!strcmp (tag, GST_TAG_TITLE)) {
+	if (info && !strcmp (tag, GST_TAG_TITLE)) {
 		if (!info->title)
 			gst_tag_list_get_string (list, tag, &(info->title));
 	}
-	else if (!strcmp (tag, GST_TAG_ARTIST)) {
+	else if (info && !strcmp (tag, GST_TAG_ARTIST)) {
 		if (!info->artist)
 			gst_tag_list_get_string (list, tag, &(info->artist));
 	}
-	else if (!strcmp (tag, GST_TAG_ISRC)) {
+	else if (info && !strcmp (tag, GST_TAG_ISRC)) {
 		gst_tag_list_get_int (list, tag, &(info->isrc));
 	}
-	else if (!strcmp (tag, GST_TAG_PERFORMER)) {
+	else if (info && !strcmp (tag, GST_TAG_PERFORMER)) {
 		if (!info->artist)
 			gst_tag_list_get_string (list, tag, &(info->artist));
 	}
@@ -1366,7 +1377,14 @@ brasero_transcode_error_on_pad_linking (BraseroTranscode *self)
 	message = gst_message_new_error (GST_OBJECT (priv->pipeline),
 					 g_error_new (BRASERO_BURN_ERROR,
 						      BRASERO_BURN_ERROR_GENERAL,
-						      "Impossible to link gstreamer plugin pads."),	/* FIXME: translate */
+						      /* Translators: This message is sent
+						       * when brasero could not link together
+						       * two gstreamer plugins so that one
+						       * sends its data to the second for further
+						       * processing. This data transmission is
+						       * done through a pad. Maybe this is a bit
+						       * too technical and should be removed? */
+						      _("Impossible to link plugin pads")),
 					 "Sent by brasero_metadata_error_on_pad_linking");
 
 	bus = gst_pipeline_get_bus (GST_PIPELINE (priv->pipeline));
@@ -1527,6 +1545,20 @@ brasero_transcode_export_caps (BraseroPlugin *plugin, gchar **error)
 			       "Philippe Rouquier",
 			       0);
 
+	output = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE|
+					 BRASERO_PLUGIN_IO_ACCEPT_PIPE,
+					 BRASERO_AUDIO_FORMAT_RAW|
+					 BRASERO_AUDIO_FORMAT_44100|
+					 BRASERO_METADATA_INFO);
+
+	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					BRASERO_AUDIO_FORMAT_UNDEFINED|
+					BRASERO_METADATA_INFO);
+
+	brasero_plugin_link_caps (plugin, output, input);
+	g_slist_free (output);
+	g_slist_free (input);
+
 	output = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE|
 					 BRASERO_PLUGIN_IO_ACCEPT_PIPE,
 					 BRASERO_AUDIO_FORMAT_RAW|
