@@ -232,27 +232,31 @@ brasero_vob_build_audio_pcm (BraseroVob *vob,
 			     GError **error)
 {
 	GstElement *queue;
+	GstElement *queue1;
+	GstElement *filter;
 	GstElement *convert;
+	GstCaps *filtercaps;
 	GstElement *resample;
 	BraseroVobPrivate *priv;
 
 	priv = BRASERO_VOB_PRIVATE (vob);
 
+	/* NOTE: this can only be used for Video DVDs as PCM cannot be used for
+	 * (S)VCDs. */
+
 	/* queue */
 	queue = gst_element_factory_make ("queue", NULL);
 	if (queue == NULL) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("queue element can't be created"));
+			     /* Translators: %s is the name of the GstElement that 
+			      * could not be created */
+			     _("%s element could not be created"),
+			     "\"Queue\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), queue);
-	g_object_set (queue,
-		      "max-size-bytes", 0,
-		      "max-size-buffers", 0,
-		      "max-size-time", (gint64) 0,
-		      NULL);
 
 	/* audioresample */
 	resample = gst_element_factory_make ("audioresample", NULL);
@@ -260,7 +264,10 @@ brasero_vob_build_audio_pcm (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("audioresample can't be created"));
+			     /* Translators: %s is the name of the GstElement that 
+			      * could not be created */
+			     _("%s element could not be created"),
+			     "\"Audioresample\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), resample);
@@ -271,13 +278,51 @@ brasero_vob_build_audio_pcm (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("audioconvert can't be created"));
+			     /* Translators: %s is the name of the GstElement that 
+			      * element could not be created */
+			     _("%s element could not be created"),
+			     "\"Audioconvert\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), convert);
 
-	gst_element_link_many (queue, resample, convert, NULL);
-	brasero_vob_link_audio (vob, queue, convert, tee, muxer);
+	/* another queue */
+	queue1 = gst_element_factory_make ("queue", NULL);
+	if (queue1 == NULL) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("%s element could not be created"),
+			     "\"Queue1\"");
+		goto error;
+	}
+	gst_bin_add (GST_BIN (priv->pipeline), queue1);
+
+	/* create a filter */
+	filter = gst_element_factory_make ("capsfilter", NULL);
+	if (filter == NULL) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("%s element could not be created"),
+			     "\"Filter\"");
+		goto error;
+	}
+	gst_bin_add (GST_BIN (priv->pipeline), filter);
+
+	/* NOTE: what about the number of channels (up to 6) ? */
+	filtercaps = gst_caps_new_full (gst_structure_new ("audio/x-raw-int",
+							   "width", G_TYPE_INT, 16,
+							   "depth", G_TYPE_INT, 16,
+							   "rate", G_TYPE_INT, 48000,
+							   NULL),
+					NULL);
+
+	g_object_set (GST_OBJECT (filter), "caps", filtercaps, NULL);
+	gst_caps_unref (filtercaps);
+
+	gst_element_link_many (queue, resample, convert, filter, queue1, NULL);
+	brasero_vob_link_audio (vob, queue, queue1, tee, muxer);
 
 	return TRUE;
 
@@ -295,7 +340,9 @@ brasero_vob_build_audio_mp2 (BraseroVob *vob,
 	GstElement *queue;
 	GstElement *queue1;
 	GstElement *encode;
+	GstElement *filter;
 	GstElement *convert;
+	GstCaps *filtercaps;
 	GstElement *resample;
 	BraseroVobPrivate *priv;
 
@@ -307,15 +354,11 @@ brasero_vob_build_audio_mp2 (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("queue element can't be created"));
+			     _("%s element could not be created"),
+			     "\"Queue\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), queue);
-	g_object_set (queue,
-		      "max-size-bytes", 0,
-		      "max-size-buffers", 0,
-		      "max-size-time", (gint64) 0,
-		      NULL);
 
 	/* audioconvert */
 	convert = gst_element_factory_make ("audioconvert", NULL);
@@ -323,7 +366,8 @@ brasero_vob_build_audio_mp2 (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("audioconvert can't be created"));
+			     _("%s element could not be created"),
+			     "\"Audioconvert\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), convert);
@@ -334,17 +378,20 @@ brasero_vob_build_audio_mp2 (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("audioresample can't be created"));
+			     _("%s element could not be created"),
+			     "\"Audioresample\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), resample);
 
+	/* encoder */
 	encode = gst_element_factory_make ("ffenc_mp2", NULL);
 	if (encode == NULL) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("ffenc_mp2 can't be created"));
+			     _("%s element could not be created"),
+			     "\"ffenc_mp2\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), encode);
@@ -355,52 +402,68 @@ brasero_vob_build_audio_mp2 (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("queue1 element can't be created"));
+			     _("%s element could not be created"),
+			     "\"Queue1\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), queue1);
-	g_object_set (queue1,
-		      "max-size-bytes", 0,
-		      "max-size-buffers", 0,
-		      "max-size-time", (gint64) 0,
-		      NULL);
 
-	if (!priv->is_video_dvd) {
-		GstElement *filter;
-		GstCaps *filtercaps;
+	/* create a filter */
+	filter = gst_element_factory_make ("capsfilter", NULL);
+	if (filter == NULL) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("%s element could not be created"),
+			     "\"Filter\"");
+		goto error;
+	}
+	gst_bin_add (GST_BIN (priv->pipeline), filter);
 
-		/* This is for (S)VCD which need to have audio at 44100 khz */
-
-		/* create a filter */
-		filter = gst_element_factory_make ("capsfilter", NULL);
-		if (filter == NULL) {
-			g_set_error (error,
-				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
-				     _("filter can't be created"));
-			goto error;
-		}
-		gst_bin_add (GST_BIN (priv->pipeline), filter);
-
-		BRASERO_JOB_LOG (vob, "Setting rate to 44100");
+	if (priv->is_video_dvd) {
+		BRASERO_JOB_LOG (vob, "Setting mp2 bitrate to 448000, 48000 khz");
+		g_object_set (encode,
+			      "bitrate", 448000, /* it could go up to 912k */
+			      NULL);
 
+		/* NOTE: what about the number of channels (up to 7.1) ? */
 		filtercaps = gst_caps_new_full (gst_structure_new ("audio/x-raw-int",
-								   "channels", G_TYPE_INT, 2,
-								   "width", G_TYPE_INT, 16,
-								   "depth", G_TYPE_INT, 16,
-								   "endianness", G_TYPE_INT, 1234,
-								   "rate", G_TYPE_INT, 44100,
-								   "signed", G_TYPE_BOOLEAN, TRUE,
+								   "rate", G_TYPE_INT, 48000,
 								   NULL),
 						NULL);
-
-		g_object_set (GST_OBJECT (filter), "caps", filtercaps, NULL);
-		gst_caps_unref (filtercaps);
-
-		gst_element_link_many (queue, convert, resample, filter, encode, queue1, NULL);
 	}
-	else
-		gst_element_link_many (queue, convert, resample, encode, queue1, NULL);
+	else if (!priv->svcd) {
+		/* VCD */
+		BRASERO_JOB_LOG (vob, "Setting mp2 bitrate to 224000, 44100 khz");
+		g_object_set (encode,
+			      "bitrate", 224000,
+			      NULL);
+
+		/* 2 channels tops */
+		filtercaps = gst_caps_new_full (gst_structure_new ("audio/x-raw-int",
+								   "channels", G_TYPE_INT, 2,
+								   "rate", G_TYPE_INT, 44100,
+								   NULL),
+						NULL);
+	}
+	else {
+		/* SVCDs */
+		BRASERO_JOB_LOG (vob, "Setting mp2 bitrate to 384000, 44100 khz");
+		g_object_set (encode,
+			      "bitrate", 384000,
+			      NULL);
+
+		/* NOTE: channels up to 5.1 or dual */
+		filtercaps = gst_caps_new_full (gst_structure_new ("audio/x-raw-int",
+								   "rate", G_TYPE_INT, 44100,
+								   NULL),
+						NULL);
+	}
+
+	g_object_set (GST_OBJECT (filter), "caps", filtercaps, NULL);
+	gst_caps_unref (filtercaps);
+
+	gst_element_link_many (queue, convert, resample, filter, encode, queue1, NULL);
 
 	brasero_vob_link_audio (vob, queue, queue1, tee, muxer);
 	return TRUE;
@@ -417,28 +480,29 @@ brasero_vob_build_audio_ac3 (BraseroVob *vob,
 			     GError **error)
 {
 	GstElement *queue;
+	GstElement *queue1;
+	GstElement *filter;
 	GstElement *encode;
 	GstElement *convert;
+	GstCaps *filtercaps;
 	GstElement *resample;
 	BraseroVobPrivate *priv;
 
 	priv = BRASERO_VOB_PRIVATE (vob);
 
+	/* NOTE: This has to be a DVD since AC3 is not supported by (S)VCD */
+
 	/* queue */
 	queue = gst_element_factory_make ("queue", NULL);
 	if (queue == NULL) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("queue element can't be created"));
+			     _("%s element could not be created"),
+			     "\"Queue\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), queue);
-	g_object_set (queue,
-		      "max-size-bytes", 0,
-		      "max-size-buffers", 0,
-		      "max-size-time", (gint64) 0,
-		      NULL);
 
 	/* audioconvert */
 	convert = gst_element_factory_make ("audioconvert", NULL);
@@ -446,7 +510,8 @@ brasero_vob_build_audio_ac3 (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("audioconvert can't be created"));
+			     _("%s element could not be created"),
+			     "\"Audioconvert\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), convert);
@@ -457,23 +522,65 @@ brasero_vob_build_audio_ac3 (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("audioresample can't be created"));
+			     _("%s element could not be created"),
+			     "\"Audioresample\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), resample);
 
+	/* create a filter */
+	filter = gst_element_factory_make ("capsfilter", NULL);
+	if (filter == NULL) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("%s element could not be created"),
+			     "\"Filter\"");
+		goto error;
+	}
+	gst_bin_add (GST_BIN (priv->pipeline), filter);
+
+	BRASERO_JOB_LOG (vob, "Setting AC3 rate to 48000");
+	/* NOTE: we may want to limit the number of channels. */
+	filtercaps = gst_caps_new_full (gst_structure_new ("audio/x-raw-int",
+							   "rate", G_TYPE_INT, 48000,
+							   NULL),
+					NULL);
+
+	g_object_set (GST_OBJECT (filter), "caps", filtercaps, NULL);
+	gst_caps_unref (filtercaps);
+
+	/* encoder */
 	encode = gst_element_factory_make ("ffenc_ac3", NULL);
 	if (encode == NULL) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("ffenc_ac3 can't be created"));
+			     _("%s element could not be created"),
+			     "\"Ffenc_ac3\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), encode);
 
-	gst_element_link_many (queue, convert, resample, encode, NULL);
-	brasero_vob_link_audio (vob, queue, encode, tee, muxer);
+	BRASERO_JOB_LOG (vob, "Setting AC3 bitrate to 448000");
+	g_object_set (encode,
+		      "bitrate", 448000, /* Maximum allowed, is it useful ? */
+		      NULL);
+
+	/* another queue */
+	queue1 = gst_element_factory_make ("queue", NULL);
+	if (queue1 == NULL) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("%s element could not be created"),
+			     "\"Queue1\"");
+		goto error;
+	}
+	gst_bin_add (GST_BIN (priv->pipeline), queue1);
+
+	gst_element_link_many (queue, convert, resample, filter, encode, queue1, NULL);
+	brasero_vob_link_audio (vob, queue, queue1, tee, muxer);
 
 	return TRUE;
 
@@ -493,13 +600,14 @@ brasero_vob_build_audio_bins (BraseroVob *vob,
 
 	priv = BRASERO_VOB_PRIVATE (vob);
 
-	/* queue */
+	/* tee */
 	tee = gst_element_factory_make ("tee", NULL);
 	if (tee == NULL) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("tee element can't be created"));
+			     _("%s element could not be created"),
+			     "\"Tee\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), tee);
@@ -517,6 +625,8 @@ brasero_vob_build_audio_bins (BraseroVob *vob,
 		if (priv->format == BRASERO_AUDIO_FORMAT_NONE)
 			priv->format = BRASERO_AUDIO_FORMAT_RAW;
 
+		/* FIXME: for the moment even if we use tee, we can't actually
+		 * encode and use more than one audio stream */
 		if (priv->format & BRASERO_AUDIO_FORMAT_RAW) {
 			/* PCM : on demand */
 			BRASERO_JOB_LOG (vob, "Adding PCM audio stream");
@@ -557,6 +667,7 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 	GstPad *sinkpad;
 	GstElement *scale;
 	GstElement *queue;
+	GstElement *queue1;
 	GstElement *filter;
 	GstElement *encode;
 	GstPadLinkReturn res;
@@ -572,15 +683,11 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("queue element can't be created"));
+			     _("%s element could not be created"),
+			     "\"Queue\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), queue);
-	g_object_set (queue,
-		      "max-size-bytes", 0,
-		      "max-size-buffers", 0,
-		      "max-size-time", (gint64) 0,
-		      NULL);
 
 	/* framerate and video type control */
 	framerate = gst_element_factory_make ("videorate", NULL);
@@ -588,7 +695,8 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("framerate can't be created"));
+			     _("%s element could not be created"),
+			     "\"Framerate\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), framerate);
@@ -602,7 +710,8 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("scale can't be created"));
+			     _("%s element could not be created"),
+			     "\"Videoscale\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), scale);
@@ -613,7 +722,8 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("filter can't be created"));
+			     _("%s element could not be created"),
+			     "\"Filter\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), filter);
@@ -623,7 +733,8 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("ffmpegcolorspace can't be created"));
+			     _("%s element could not be created"),
+			     "\"Ffmepgcolorspace\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), colorspace);
@@ -633,7 +744,8 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("mpeg2enc can't be created"));
+			     _("%s element could not be created"),
+			     "\"Mpeg2enc\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (priv->pipeline), encode);
@@ -642,12 +754,15 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		g_object_set (encode,
 			      "format", 8,
 			      NULL);
-	/* NOTE: there is another option to improve compatibility with vcdimager
-	 * but that would mean be sure that it's the next. */
-	else if (priv->svcd)
+	else if (priv->svcd) {
+		/* Option to improve compatibility with vcdimager */
+		g_object_set (encode,
+			      "dummy-svcd-sof", TRUE,
+			      NULL);
 		g_object_set (encode,
 			      "format", 4,
 			      NULL);
+	}
 	else
 		g_object_set (encode,
 			      "format", 1,
@@ -758,29 +873,52 @@ brasero_vob_build_video_bin (BraseroVob *vob,
 		}
 	}
 
-	value = NULL;
-	result = brasero_job_tag_lookup (BRASERO_JOB (vob),
-					 BRASERO_VIDEO_OUTPUT_ASPECT,
-					 &value);
-	if (result == BRASERO_BURN_OK && value) {
-		gint aspect;
+	if (priv->is_video_dvd || priv->svcd) {
+		value = NULL;
+		result = brasero_job_tag_lookup (BRASERO_JOB (vob),
+						 BRASERO_VIDEO_OUTPUT_ASPECT,
+						 &value);
+		if (result == BRASERO_BURN_OK && value) {
+			gint aspect;
 
-		aspect = g_value_get_int (value);
-		if (aspect == BRASERO_VIDEO_ASPECT_4_3) {
-			g_object_set (encode,
-				      "aspect", 2,
-				      NULL);
-		}
-		else if (aspect == BRASERO_VIDEO_ASPECT_16_9) {
-			g_object_set (encode,
-				      "aspect", 3,
-				      NULL);	
+			aspect = g_value_get_int (value);
+			if (aspect == BRASERO_VIDEO_ASPECT_4_3) {
+				BRASERO_JOB_LOG (vob, "Setting ration 4:3");
+				g_object_set (encode,
+					      "aspect", 2,
+					      NULL);
+			}
+			else if (aspect == BRASERO_VIDEO_ASPECT_16_9) {
+				BRASERO_JOB_LOG (vob, "Setting ration 16:9");
+				g_object_set (encode,
+					      "aspect", 3,
+					      NULL);	
+			}
 		}
 	}
+	else {
+		/* VCDs only support 4:3 */
+		BRASERO_JOB_LOG (vob, "Setting ration 4:3");
+		g_object_set (encode,
+			      "aspect", 2,
+			      NULL);
+	}
 
-	gst_element_link_many (queue, framerate, scale, colorspace, filter, encode, NULL);
+	/* another queue */
+	queue1 = gst_element_factory_make ("queue", NULL);
+	if (queue1 == NULL) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("%s element could not be created"),
+			     "\"Queue1\"");
+		goto error;
+	}
+	gst_bin_add (GST_BIN (priv->pipeline), queue1);
 
-	srcpad = gst_element_get_static_pad (encode, "src");
+	gst_element_link_many (queue, framerate, scale, colorspace, filter, encode, queue1, NULL);
+
+	srcpad = gst_element_get_static_pad (queue1, "src");
 	sinkpad = gst_element_get_request_pad (muxer, "video_%d");
 	res = gst_pad_link (srcpad, sinkpad);
 	BRASERO_JOB_LOG (vob, "Linked video bin to muxer == %d", res)
@@ -824,7 +962,8 @@ brasero_vob_build_pipeline (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("source can't be created"));
+			     _("%s element could not be created"),
+			     "\"Source\"");
 		return FALSE;
 	}
 	gst_bin_add (GST_BIN (pipeline), source);
@@ -838,7 +977,8 @@ brasero_vob_build_pipeline (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("decode can't be created"));
+			     _("%s element could not be created"),
+			     "\"Decodebin\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (pipeline), decode);
@@ -850,7 +990,8 @@ brasero_vob_build_pipeline (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("mplex can't be created"));
+			     _("%s element could not be created"),
+			     "\"Mplex\"");
 		goto error;
 	}
 	gst_bin_add (GST_BIN (pipeline), muxer);
@@ -863,9 +1004,9 @@ brasero_vob_build_pipeline (BraseroVob *vob,
 		g_object_set (muxer,
 			      "format", 4,
 			      NULL);
-	else
+	else	/* This should be 1 but it causes frame drops */
 		g_object_set (muxer,
-			      "format", 1,
+			      "format", 4,
 			      NULL);
 
 	/* create sink */
@@ -876,7 +1017,8 @@ brasero_vob_build_pipeline (BraseroVob *vob,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("sink can't be created"));
+			     _("%s element could not be created"),
+			     "\"Sink\"");
 		return FALSE;
 	}
 	g_object_set (sink,
@@ -953,7 +1095,7 @@ brasero_vob_start (BraseroJob *job,
 		priv->is_video_dvd = TRUE;
 
 	BRASERO_JOB_LOG (job,
-			 "Got output type (is DVD %i, is SVCD %i",
+			 "Got output type (is DVD %i, is SVCD %i)",
 			 priv->is_video_dvd,
 			 priv->svcd);
 
@@ -1061,6 +1203,30 @@ brasero_vob_export_caps (BraseroPlugin *plugin, gchar **error)
 			       "Philippe Rouquier",
 			       0);
 
+	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					BRASERO_AUDIO_FORMAT_UNDEFINED|
+					BRASERO_VIDEO_FORMAT_UNDEFINED|
+					BRASERO_METADATA_INFO);
+	output = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					 BRASERO_AUDIO_FORMAT_MP2|
+					 BRASERO_AUDIO_FORMAT_44100|
+					 BRASERO_METADATA_INFO|
+					 BRASERO_VIDEO_FORMAT_VCD);
+	brasero_plugin_link_caps (plugin, output, input);
+	g_slist_free (output);
+
+	output = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					 BRASERO_AUDIO_FORMAT_AC3|
+					 BRASERO_AUDIO_FORMAT_MP2|
+					 BRASERO_AUDIO_FORMAT_RAW|
+					 BRASERO_AUDIO_FORMAT_44100|
+					 BRASERO_AUDIO_FORMAT_48000|
+					 BRASERO_METADATA_INFO|
+					 BRASERO_VIDEO_FORMAT_VIDEO_DVD);
+	brasero_plugin_link_caps (plugin, output, input);
+	g_slist_free (output);
+	g_slist_free (input);
+
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					BRASERO_AUDIO_FORMAT_UNDEFINED|
 					BRASERO_VIDEO_FORMAT_UNDEFINED);
@@ -1081,6 +1247,5 @@ brasero_vob_export_caps (BraseroPlugin *plugin, gchar **error)
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 	g_slist_free (input);
-
 	return BRASERO_BURN_OK;
 }
