@@ -115,7 +115,7 @@ brasero_vcd_imager_generate_xml_file (BraseroProcess *process,
 	gchar *name;
 	gint i;
 
-	BRASERO_JOB_LOG (process, "Creating DVD layout xml file(%s)", path);
+	BRASERO_JOB_LOG (process, "Creating (S)VCD layout xml file (%s)", path);
 
 	xml = xmlNewTextWriterFilename (path, 0);
 	if (!xml)
@@ -214,6 +214,8 @@ brasero_vcd_imager_generate_xml_file (BraseroProcess *process,
 	if (success < 0)
 		goto error;
 
+	/* NOTE: no need to convert a possible non compliant name as this will 
+	 * be done by vcdimager. */
 	name = NULL;
 	brasero_job_get_audio_title (BRASERO_JOB (process), &name);
 	success = xmlTextWriterWriteElement (xml,
@@ -469,7 +471,7 @@ brasero_vcd_imager_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* NOTE: it seems that cdrecord can burn cue files on the fly */
 	brasero_plugin_define (plugin,
 			       "vcdimager",
-			       _("use vcdimager to convert a set of files to burn to SVCDs"),
+			       _("Use vcdimager to create SVCDs"),
 			       "Philippe Rouquier",
 			       1);
 
@@ -481,10 +483,20 @@ brasero_vcd_imager_export_caps (BraseroPlugin *plugin, gchar **error)
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					BRASERO_AUDIO_FORMAT_MP2|
 					BRASERO_AUDIO_FORMAT_44100|
-					BRASERO_VIDEO_FORMAT_VCD);
+					BRASERO_VIDEO_FORMAT_VCD|
+					BRASERO_METADATA_INFO);
+
 	output = brasero_caps_image_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					 BRASERO_IMAGE_FORMAT_CUE);
 
+	brasero_plugin_link_caps (plugin, output, input);
+	g_slist_free (input);
+
+	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					BRASERO_AUDIO_FORMAT_MP2|
+					BRASERO_AUDIO_FORMAT_44100|
+					BRASERO_VIDEO_FORMAT_VCD);
+
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 	g_slist_free (input);
